<?php
    /************************************************************************
        Class:          mct_CConfigFile
        Inheritance:    mct_CFileCFG
        Description:    Object for a complete ConfigFile
    ************************************************************************/
    include_once("../inc/mct_general.inc.php");
    include_once("../inc/mct_func.inc.php");
    include_once("../inc/mct_CReturn.class.php");
    include_once("../inc/mct_CFileCFG.class.php");
    include_once("../inc/mct_CInterface.class.php");
    include_once("../inc/mct_CDebug.class.php");
    include_once("../inc/mct_CDbQuery.class.php");

    class mct_CConfigFile extends mct_CFileCFG
    {
        var $strCreationDate;
        var $strLastChangeDate;
        var $nCreatorUserId;
        var $nLastChangerUserId;
        var $strDirectory;
        var $strWorkDir;
        var $nRefresh;
        var $nInterval;
        var $strWriteExpires;
        var $strIconDir;
        var $nWriteStatus;
        var $arrInterfaces = array();
        var $objGlobalInterface;

        /*-----------------------------------------------------------------------
            CONSTRUCTOR
        -----------------------------------------------------------------------*/
        function mct_CConfigFile()
        {
            $this->objGlobalInterface = new mct_CInterface;
            $this->mct_init();
        }

        /*-----------------------------------------------------------------------
            Method:         Interface Functions
            Description:    get and set Methods for filling the Properties
        -----------------------------------------------------------------------*/
        function mct_getCreationDate()               { return $this->strCreationDate;    }
        function mct_getLastChangeDate()             { return $this->strLastChangeDate;  }
        function mct_getCreatorUserId()              { return $this->nCreatorUserId;     }
        function mct_getLastChangerUserId()          { return $this->nLastChangerUserId; }
        function mct_getDirectory()                  { return $this->strDirectory;       }
        function mct_getWorkDir()                    { return $this->strWorkDir;         }
        function mct_getRefresh()                    { return $this->nRefresh;           }
        function mct_getInterval()                   { return $this->nInterval;          }
        function mct_getWriteExpires()               { return $this->strWriteExpires;    }
        function mct_getIconDir()                    { return $this->strIconDir;         }
        function mct_getWriteStatus()                { return $this->nWriteStatus;       }
        function mct_getInterfaces()                 { return $this->arrInterfaces;      }

        function mct_setCreationDate( $strValue )    { if( is_string($strValue) ) $this->strCreationDate = $strValue;   }
        function mct_setLastChangeDate( $strValue )  { if( is_string($strValue) ) $this->strLastChangeDate = $strValue; }
        function mct_setCreatorUserId( $nValue )     { if( is_int($nValue) ) $this->nCreatorUserId = $nValue;           }
        function mct_setLastChangerUserId( $nValue ) { if( is_int($nValue) ) $this->nLastChangerUserId = $nValue;       }
        function mct_setWorkDir( $strValue )
        {
            // Check for Value to edit
            if( is_string($strValue) && strlen($strValue) > 0 )
                $this->strWorkDir = mct_ConvertPath($strValue);
        }
        function mct_setRefresh( $nValue )           { if( is_int($nValue) ) $this->nRefresh = $nValue;                 }
        function mct_setInterval( $nValue )          { if( is_int($nValue) ) $this->nInterval = $nValue;                }
        function mct_setWriteExpires( $strValue )    { if( is_string($strValue) ) $this->strWriteExpires = $strValue;   }
        function mct_setIconDir( $strValue )         { if( is_string($strValue) ) $this->strIconDir = $strValue;        }
        function mct_setDirectory( $strValue )
        {
            // Check for Value to edit
            if( is_string($strValue) && strlen($strValue) > 0 )
                $this->strDirectory = mct_ConvertPath($strValue);
        }
        function mct_setInterfaces( $arrValue )
        {
            if( is_array($arrValue) )
                $this->arrInterfaces = $arrValue;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_init
            Description:    Init Properties of Object
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_init()
        {
            parent::mct_init();
            $this->strCreationDate      = "";
            $this->strLastChangeDate    = "";
            $this->nCreatorUserId       = -1;
            $this->nLastChangerUserId   = -1;
            $this->strDirectory         = "";
            $this->strWorkDir           = "";
            $this->nRefresh             = -1;
            $this->nInterval            = -1;
            $this->strWriteExpires      = "";
            $this->strIconDir           = "";
            $this->nWriteStatus         = 0;
            $this->arrInterfaces        = array();
        }

        /*-----------------------------------------------------------------------
            Method:         mct_free
            Description:    Free result and clean up
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_free()
        {
            // Free Inner Objects
            if(isset($this->objGlobalInterface)) $this->objGlobalInterface->mct_free();
            // Free Parent
            parent::mct_free();
            // Set Object to NULL
            $this = null;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_writedb
            Description:    Write or Updates Object to Database
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_writedb()
        {
            global $debug;

            $bReturn = false;

            // Create Query-Object
            $objDB = new mct_CDbQuery;

            // Check if Object has an ID
            if( $this->nId == -1 )
            {
                // Set GlobalInterface Property to true
                $this->objGlobalInterface->mct_setGlobalIf(true);
                // Write Global Interface Properties
                $this->objGlobalInterface->mct_writedb();

                // Get New ID on tconfigfile
                $this->nId = $this->mct_getNewID('tconfigfile');

                // get actual Time
                $this->strCreationDate = $this->strLastChangeDate = date("Y-m-d", time());

                // Create INSERT Query
                $objDB->mct_setQuery("INSERT INTO tconfigfile(`ID`, `Name`, `CreationDate`, `LastChangeDate`, `Directory`, "
                    . "`WorkDir`, `Refresh`, `Interval`, `WriteExpires`, `IconDir`, "
                    . "`fkCreatorUserID`, `fkLastChangerUserID`, `fkGlobalinterfaceID`) VALUES( "
                    . $this->nId
                    . ",  '" . $objDB->mct_DBStr($this->strName) . "'"
                    . ", '" . $objDB->mct_getSqlDateSeperator() . $this->strCreationDate . $objDB->mct_getSqlDateSeperator() . "'"
                    . ", '" . $objDB->mct_getSqlDateSeperator() . $this->strLastChangeDate . $objDB->mct_getSqlDateSeperator() . "'"
                    . ",  '" . $this->strDirectory . "'"
                    . ",  '" . $this->strWorkDir . "'"
                    . ",   " . $this->nRefresh
                    . ",   " . $this->nInterval
                    . ",  '" . $this->strWriteExpires . "'"
                    . ",  '" . $this->strIconDir . "'"
                    . ",   " . $this->nCreatorUserId
                    . ",   " . $this->nLastChangerUserId
                    . ",   " . $this->objGlobalInterface->mct_getId()
                    . " )");
                // Execute Query
                if( ! $objDB->mct_execute() )
                {
                    // Error happend
                    $objDB->objReturn->mct_print();
                }
                else
                {
                    $bReturn = true;
                    // Loop Interface-Array and write into Merge-Table
                    foreach( $this->arrInterfaces as $Val )
                    {
                        // Get New ID on tz_ifcfg
                        $nNewId = $this->mct_getNewID('tz_ifcfg');
                        // Create INSERT Query
                        $objDB->mct_setQuery("INSERT INTO tz_ifcfg(`ID`, `fkInterfaceID`, `fkConfigFileID`) VALUES("
                            .$nNewId . "," . $Val . "," . $this->nId
                            .")");
                        // Execute Query
                        if( ! $objDB->mct_execute() )
                        {
                            // Error happend
                            $objDB->objReturn->mct_print();
                            $bReturn = false;
                            break;
                        }
                    }
                }
            }
            // Object has ID, so Update it!
            else
            {
                // Set GlobalInterface Property to true
                $this->objGlobalInterface->mct_setGlobalIf(true);
                // Write Global Interface Properties
                $this->objGlobalInterface->mct_writedb();

                // get actual Time
                $this->strLastChangeDate = date("Y-m-d", time());

                // Create UPDATE Query
                $objDB->mct_setQuery("UPDATE tconfigfile SET"
                    ."  `Name`='"               . $objDB->mct_DBStr($this->strName) . "' "
                    .", `LastChangeDate`='"     . $objDB->mct_getSqlDateSeperator() . $this->strLastChangeDate . $objDB->mct_getSqlDateSeperator() . "' "
                    .", `Directory`='"          . $this->strDirectory . "' "
                    .", `WorkDir`='"            . $this->strWorkDir . "' "
                    .", `Refresh`="             . $this->nRefresh
                    .", `Interval`="            . $this->nInterval
                    .", `WriteExpires`='"       . $this->strWriteExpires . "' "
                    .", `IconDir`='"            . $this->strIconDir . "' "
                    .", `fkLastChangerUserID`=" . $this->nLastChangerUserId
                    .", `fkGlobalinterfaceID`=" . $this->objGlobalInterface->mct_getId()
                    ." WHERE `ID`="             . $this->nId);
                // Execute Query
                if( ! $objDB->mct_execute() )
                {
                    // Error happend
                    $objDB->objReturn->mct_print();
                }
                else
                {
                    $bReturn = true;
                    // Create DELETE Query -> Delete Records on tz_ifcfg
                    $objDB->mct_setQuery("DELETE FROM tz_ifcfg WHERE `fkConfigFileID`=" . $this->nId);
                    // Execute Query
                    if( ! $objDB->mct_execute() )
                    {
                        // Error happend
                        $objDB->objReturn->mct_print();
                    }
                    else
                    {
                        $bReturn = true;
                        // Loop Interface-Array and write into Merge-Table
                        foreach( $this->arrInterfaces as $Val )
                        {
                            // Get New ID on tz_ifcfg
                            $nNewId = $this->mct_getNewID('tz_ifcfg');
                            // Create INSERT Query
                            $objDB->mct_setQuery("INSERT INTO tz_ifcfg(`ID`, `fkInterfaceID`, `fkConfigFileID`) VALUES("
                                .$nNewId . "," . $Val . "," . $this->nId
                                .")");
                            // Execute Query
                            if( ! $objDB->mct_execute() )
                            {
                                // Error happend
                                $objDB->objReturn->mct_print();
                                $bReturn = false;
                                break;
                            }
                        }
                    }
                }
            }
            // Free Object
            $objDB->mct_free();
            if( !$bReturn && defined("_DEBUG_MODE_") && isset($debug) ) $debug->mct_add_stack($this, "ERROR", __FILE__, __LINE__);
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_writefile_complete
            Description:    Write complete ConfigFile
            ---------------------------------------------------------------------
            Parameter:      strFilename        String of Filename ("xy.txt")
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_writefile_complete( $strFilename = "" )
        {
            global $debug;
            global $gArrMctIni;

            $bReturn = false;
            // Reset Status Properties
             $this->nWriteStatus = 0;

            // check for Save-Mode
            if( defined("_SAVE_MODE_") )
            {
                echo "<p><b>Warning:</b> Action can NOT proceed because SAVE-MODE is ON!</p>";
                return $bReturn;
            }

            // Validate
            if( $strFilename != "" && $this->nId != -1 )
            {
                // Generate Filestring
                $strFile = $this->strDirectory . $strFilename;

                // Write File
                $objReturn = mct_write_file($strFile, "# File BEGIN", "renew");
                // Check for Errors
                if( ! $objReturn->mct_iserror() )
                {
                    mct_write_file($strFile, "#     ___   ___  _____ ______  ", "append");
                    mct_write_file($strFile, "#    /   | /   |.  ___\__   _| ", "append");
                    mct_write_file($strFile, "#   / /| |/ /| || |      | |   ", "append");
                    mct_write_file($strFile, "#  / / |___/ | || |___   | |   ", "append");
                    mct_write_file($strFile, "# /_/        |_| .____/  |_|   ", "append");
                    mct_write_file($strFile, "# MCT - MRTG Configuration Tool", "append");
                    mct_write_file($strFile, " ", "append");
                    mct_write_file($strFile, "# Automatic Generated File by MCT", "append");
                    mct_write_file($strFile, "# Developer Markus Baettig & Juerg Zgraggen", "append");
                    mct_write_file($strFile, " ", "append");
                    mct_write_file($strFile, " ", "append");

                    // Write Global Interface Properties
                    mct_write_file($strFile, "# Global ConfigFile Properties", "append");
                    // To have the MRTG Output in the defined Webrootfolder, the WWWRoot from INI has to be concated.
                   if( $this->strWorkDir != "" )      mct_write_file($strFile, "WorkDir: " . mct_ConvertPath($gArrMctIni["General"]["WWWRoot"].$this->strWorkDir, true), "append");
                   if( $this->nRefresh > 0 )          mct_write_file($strFile, "Refresh: " . $this->nRefresh, "append");
                   if( $this->nInterval > 0 )         mct_write_file($strFile, "Interval: " . $this->nInterval, "append");
                   if( $this->strWriteExpires != "" ) mct_write_file($strFile, "WriteExpires: " . $this->strWriteExpires, "append");
                   if( $this->strIconDir != "" )      mct_write_file($strFile, "IconDir: " . $this->strIconDir, "append");
                   mct_write_file($strFile, " ", "append");
                   mct_write_file($strFile, " ", "append");

                    // Write Global Interface Properties
                    mct_write_file($strFile, "# Global Interface Properties", "append");
                    if( $this->objGlobalInterface->mct_isvalid() ) $this->objGlobalInterface->mct_writefile($strFile, "_", false);

                    // Loop Interface-Array and write into Merge-Table
                    foreach( $this->arrInterfaces as $Val )
                    {
                        // Generate Interface Object
                        $objInterface = new mct_CInterface;

                        // Write Breaks
                        mct_write_file($strFile, " ", "append");
                        mct_write_file($strFile, " ", "append");

                        // Get Interface from DB
                        $objInterface->mct_getfromdb($Val);
                        // Write In
                        $objInterface->mct_writefile($strFile);
                        // Free Object
                        $objInterface->mct_free();

                        // Increase nWriteStatus
                        $this->nWriteStatus++;
                    }
                    mct_write_file($strFile, " ", "append");
                    mct_write_file($strFile, "# File END", "append", false);
                    $bReturn = true;
                }
                else $objReturn->mct_print();
            }
            if( !$bReturn && defined("_DEBUG_MODE_") && isset($debug) ) $debug->mct_add_stack($this, "ERROR", __FILE__, __LINE__);
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_getfromdb
            Description:    Get Object from Database
            ---------------------------------------------------------------------
            Parameter:      nId            Integer of Record ID
            ---------------------------------------------------------------------
            Return:         Boolean        true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_getfromdb( $nId = -1 )
        {
            global $debug;

            $bReturn = false;

            // Create Query-Object
            $objDB = new mct_CDbQuery;

            // Generate Query
            $objDB->mct_setQuery("SELECT * FROM tconfigfile WHERE `ID` = $nId");
            // Execute Query and check for Data
            if( ! $objDB->mct_execute() )
            {
                // Error happend or no Record in DB
                $objDB->objReturn->mct_print();
                $objDB->mct_print(false);
            }
            elseif( $objDB->mct_getRecordCount() == 0 )
            {
                // Print DB-Object
                // $objDB->mct_print(false);
            }
            else
            {
                // Fill Attributes
                $this->nId                  = (int)$objDB->objRow->ID;
                $this->strName              = $objDB->objRow->Name;
                $this->strCreationDate      = $objDB->objRow->CreationDate;
                $this->strLastChangeDate    = $objDB->objRow->LastChangeDate;
                $this->nCreatorUserId       = (int)$objDB->objRow->fkCreatorUserID;
                $this->nLastChangerUserId   = (int)$objDB->objRow->fkLastChangerUserID;
                $this->strDirectory         = $objDB->objRow->Directory;
                $this->strWorkDir           = $objDB->objRow->WorkDir;
                $this->nRefresh             = (int)$objDB->objRow->Refresh;
                $this->nInterval            = (int)$objDB->objRow->Interval;
                $this->strWriteExpires      = $objDB->objRow->WriteExpires;
                $this->strIconDir           = $objDB->objRow->IconDir;

                // Get Global Interface Properties
                $this->objGlobalInterface->mct_getfromdb($objDB->objRow->fkGlobalInterfaceID);

                $objDBInterfaces = new mct_CDbQuery;
                // Generate Query for all Interfaces of ConfigFile
                $objDBInterfaces->mct_setQuery("SELECT fkInterfaceID FROM tz_ifcfg WHERE `fkConfigFileID` = " . $this->nId);
                // Execute Query
                if( ! $objDBInterfaces->mct_execute() )
                {
                    // Error happend
                    $objDBInterfaces->objReturn->mct_print();
                }
                else
                {
                    // Fill Interfaces
                    for( $i=0; $i < $objDBInterfaces->mct_getRecordCount(); $i++ )
                    {
                        $this->arrInterfaces[$i] = $objDBInterfaces->objRow->fkInterfaceID;
                        $objDBInterfaces->mct_getNext();
                    }
                    $bReturn = true;
                }
                $objDBInterfaces->mct_free();
            }
            $objDB->mct_free();
            if( !$bReturn && defined("_DEBUG_MODE_") && isset($debug) ) $debug->mct_add_stack($this, "ERROR", __FILE__, __LINE__);
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_deletefromdb
            Description:    Delete a Record from a Table
            ---------------------------------------------------------------------
            Return:         Boolean          true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_deletefromdb()
        {
            global $debug;

            $bReturn = false;
            if( $this->nId > -1 )
            {
                if( parent::mct_deletefromdb($this->nId, "tconfigfile") )
                {
                     // delete GlobalInterface on Object
                     $this->objGlobalInterface->mct_deletefromdb($this->objGlobalInterface->mct_getId());

                     // delete all records in tz_ifcfg
                     $objDel = new mct_CDbQuery;
                     // Generate Query
                     $objDel->mct_setQuery("DELETE FROM tz_ifcfg WHERE `fkConfigFileID`=" . $this->nId);
                     // Execute Query and check for Error
                     if( $objDel->mct_execute() ) $bReturn = true;
                     else $objDel->objReturn->mct_print();
                     $objDel->mct_free();
                }
            }
            if( !$bReturn && defined("_DEBUG_MODE_") && isset($debug) ) $debug->mct_add_stack($this, "ERROR", __FILE__, __LINE__);
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print
            Description:    Print Object
            ---------------------------------------------------------------------
            Parameter:      bAll            For Parent Object Information
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print( $bAll = true )
        {
            echo "<hr>";
            echo "<table border='1' cellspacing='0' cellpadding='0'><tr><td>";
            echo "<span style='color:red'><b>CConfigFile Object</b></span>";
            // Check if Print of Parent is desired
            if( $bAll ) parent::mct_print();
            echo "<hr>";
            echo "<b>CConfigFile Object</b><br>";
            echo "<table border='0'>";
            echo "<tr valign='top'><td><b>Interfaces:</b></td><td>";
            print_r($this->arrInterfaces);
            echo "</td></tr>";
            echo "<tr valign='top'><td><b>CreationDate:</b></td><td>" . $this->strCreationDate . "</td></tr>";
            echo "<tr valign='top'><td><b>LastChangeDate:</b></td><td>" . $this->strLastChangeDate . "</td></tr>";
            echo "<tr valign='top'><td><b>CreatorUserId:</b></td><td>" . $this->nCreatorUserId . "</td></tr>";
            echo "<tr valign='top'><td><b>LastChangerUserId:</b></td><td>" . $this->nLastChangerUserId . "</td></tr>";
            echo "<tr valign='top'><td><b>Directory:</b></td><td>" . $this->strDirectory . "</td></tr>";
            echo "<tr valign='top'><td><b>WorkDir:</b></td><td>" . $this->strWorkDir . "</td></tr>";
            echo "<tr valign='top'><td><b>Refresh:</b></td><td>" . $this->nRefresh . "</td></tr>";
            echo "<tr valign='top'><td><b>Interval:</b></td><td>" . $this->nInterval . "</td></tr>";
            echo "<tr valign='top'><td><b>WriteExpires:</b></td><td>" . $this->strWriteExpires . "</td></tr>";
            echo "<tr valign='top'><td><b>IconDir:</b></td><td>" . $this->strIconDir . "</td></tr>";
            echo "<tr valign='top'><td><b>WriteStatus:</b></td><td>" . $this->nWriteStatus . "</td></tr>";
            echo "<tr valign='top'><td><b>GlobalInterface</b></td><td>";
                $this->objGlobalInterface->mct_print();
            echo "</td></tr>";
            echo "</table>";
            echo "</td></tr></table>";
        }
    }
?>
