<?php
    /************************************************************************
        Class:          mct_CDbObject
        Inheritance:    non (Base class)
        Description:    Basic abstract Database-Class
    ************************************************************************/
    include_once("../inc/mct_general.inc.php");
    include_once("../inc/mct_func.inc.php");
    include_once("../inc/mct_CReturn.class.php");
    include_once("../inc/mct_CDebug.class.php");

    class mct_CDbObject
    {
        var $strAccessMode;         // Defines AccessMode (odbc or mysql)
        var $strHost;               // Defines Host (only MySQL)
        var $strOdbcDsn;            // Defines DSN (only ODBC)
        var $strUser;               // AccessUser for Database
        var $strPassword;           // Password for Database
        var $strDb;                 // Name of Database
        var $strSqlDateSeparator;   // Special Date Separator
        var $link;                  // Connection link Ressource
        var $res;                   // Result Ressource
        var $objRow;                // Object for actual fetched Row
        var $objReturn;             // Return Object

        /*-----------------------------------------------------------------------
            NO CONSTRUCTOR ! Class is ABSTRACT
        -----------------------------------------------------------------------*/

        /*-----------------------------------------------------------------------
            Method:         mct_init
            Description:    Initialize Properties
        -----------------------------------------------------------------------*/
        function mct_init()
        {
            global $gArrMctIni;
            // Initialize Standards
            $this->strAccessMode = strtolower($gArrMctIni["Database"]["AccessMode"]);

            // check for TestMode and change Database
            if ( ! defined("_TEST_MODE_") )
            {
                if( $this->strAccessMode == "odbc" )
                {
                    $this->strOdbcDsn = $gArrMctIni["Odbc"]["Dsn"];
                    $this->strUser = $gArrMctIni["Odbc"]["User"];
                    $this->strPassword = $gArrMctIni["Odbc"]["Password"];
                    $this->strSqlDateSeparator = "";
                }
                else
                {
                    $this->strHost = $gArrMctIni["MySQL"]["Host"];
                    $this->strUser = $gArrMctIni["MySQL"]["User"];
                    $this->strPassword = $gArrMctIni["MySQL"]["Password"];
                    $this->strDb = $gArrMctIni["MySQL"]["Db"];
                    $this->strSqlDateSeparator = "#";
                }
            }
            else
            {
                if( $this->strAccessMode == "odbc" ) // Bei Testmodus Test-DB benutzen
                {
                    $this->strOdbcDsn = $gArrMctIni["OdbcTest"]["Dsn"];
                    $this->strUser = $gArrMctIni["OdbcTest"]["User"];
                    $this->strPassword = $gArrMctIni["OdbcTest"]["Password"];
                    $this->strSqlDateSeparator = "";
                }
                else
                {
                    $this->strHost = $gArrMctIni["MySQLTest"]["Host"];
                    $this->strUser = $gArrMctIni["MySQLTest"]["User"];
                    $this->strPassword = $gArrMctIni["MySQLTest"]["Password"];
                    $this->strDb = $gArrMctIni["MySQLTest"]["Db"];
                    $this->strSqlDateSeparator = "#";
                }
            }

            // Create Return Object
            $this->objReturn = new mct_CReturn();
        }

        /*-----------------------------------------------------------------------
            Method:         Interface Functions
            Description:    get and set Methods for filling the Properties
        -----------------------------------------------------------------------*/
        function mct_getAccessMode()        { return $this->strAccessMode;       }
        function mct_getHost()              { return $this->strHost;             }
        function mct_getUser()              { return $this->strUser;             }
        function mct_getPassword()          { return $this->strPassword;         }
        function mct_getDb()                { return $this->strDb;               }
        function mct_getSqlDateSeperator()  { return $this->strSqlDateSeparator; }
        function mct_getOdbcDsn()           { return $this->strOdbcDsn;          }
        function mct_setHost($strValue)     { if( is_string($strValue) ) $this->strHost = $strValue;     }
        function mct_setUser($strValue)     { if( is_string($strValue) ) $this->strUser = $strValue;     }
        function mct_setPassword($strValue) { if( is_string($strValue) ) $this->strPassword = $strValue; }
        function mct_setDb($strValue)       { if( is_string($strValue) ) $this->strDb = $strValue;       }

        /*-----------------------------------------------------------------------
            Method:         mct_getNext
            Description:    Get next Row-Object
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         Boolean        true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_getNext()
        {
            global $debug;
            $bReturn = false;

            if( defined("_DEBUG_MODE_") && isset($debug) && !defined("_MCT_CDBOBJECT_GETNEXT_FUNCTION_") )
            {
                // set define, that the Information only appears one time in the Debugger and not on each call!
                define("_MCT_CDBOBJECT_GETNEXT_FUNCTION_",  true);
                $debug->mct_add_information("mct_CDbObject::mct_getNext() reduced Error Output by PHP @", __FILE__, __LINE__);
            }

            if( $this->strAccessMode == "odbc" )
            {
                if( is_resource($this->res)
                    && $this->objRow = mct_odbc_fetch_object($this->res) )
                        $bReturn = true;
            }
            else
            {
                if( is_resource($this->res)
                    && $this->objRow = @mysql_fetch_object($this->res) )
                        $bReturn = true;
            }
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_seek_first
            Description:    Seek to First DataRow
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         Boolean        true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_seek_first()
        {
            global $debug;

            if( defined("_DEBUG_MODE_") && isset($debug) && !defined("_MCT_CDBOBJECT_SEEKFIRST_FUNCTION_") )
            {
                // set define, that the Information only appears one time in the Debugger and not on each call!
                define("_MCT_CDBOBJECT_SEEKFIRST_FUNCTION_",  true);
                $debug->mct_add_information("mct_CDbObject::mct_seek_first() reduced Error Output by PHP @", __FILE__, __LINE__);
            }

            // Check Access-Mode
            if( $this->strAccessMode == "odbc" )
            {
                // Check Resource
                if( is_resource($this->res) )
                {
                    @odbc_fetch_row($this->res, 0);                     // Set Counter to First Element
                    $this->objRow = mct_odbc_fetch_object($this->res);  // Fetch Row to Row-Object
                }
            }
            else
            {
                // Check Resource
                if( is_resource($this->res) )
                {
                    @mysql_data_seek($this->res, 0);                 // Set Counter to First Element
                    $this->objRow = @mysql_fetch_object($this->res); // Fetch Row to Row-Object
                }
            }
        }

        /*-----------------------------------------------------------------------
            Method:         mct_DBStr
            Description:    Converts the Inputstring for Database
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         Boolean        true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_DBStr($str)
        {
            global $debug;
            global $gArrMctIni;
            $ret = $str;

            // Check Access-Mode
            if( strtolower($gArrMctIni["Database"]["AccessMode"]) == "odbc" )
            {
                if( defined("_DEBUG_MODE_") && isset($debug) && !defined("_MCT_CDBOBJECT_DBSTR_FUNCTION_") )
                {
                    // set define, that the Warning only appears one time in the Debugger and not on each call!
                    define("_MCT_CDBOBJECT_DBSTR_FUNCTION_",  true);
                    $debug->mct_add_warning("mct_CDbObject::mct_DBStr() in ODBC-Mode: Character ' (High Comma) will be cropped.", __FILE__, __LINE__);
                }
                // should be '', but '' would replaced by null! so replace it to "
                $ret = str_replace("'", "\"", $ret);
            }
            else
            {
                $ret = str_replace("'", "\\'", $ret);
            }
            return $ret;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_free
            Description:    Free result, close Connections and clean up
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_free()
        {
            global $debug;
            if( defined("_DEBUG_MODE_") && isset($debug) && !defined("_MCT_CDBOBJECT_FREE_FUNCTION_") )
            {
                // set define, that the Information only appears one time in the Debugger and not on each call!
                define("_MCT_CDBOBJECT_FREE_FUNCTION_",  true);
                $debug->mct_add_information("mct_CDbObject::mct_free() reduced Error Output by PHP @", __FILE__, __LINE__);
            }

            // Check Resource
            if( is_resource($this->res) && $this->res )
            {
                // Check Access-Mode and free Result
                if( $this->strAccessMode == "odbc" )
                    @odbc_free_result($this->res);
                else  @mysql_free_result($this->res);
            }
            $this->objRow = null;

            // Free Inner Objects
            if( isset($this->objReturn) ) $this->objReturn->mct_free();

            // Check if Connection is open and close it
            if( $this->strAccessMode == "odbc" )
                if( $this->link ) @odbc_close($this->link);
            else if( $this->link ) @mysql_close($this->link);

            // DO NOT SET Object to NULL! Class is ABSTRACT and can't be an Object
            // Just Init its Properties
            $this->mct_init();
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print
            Description:    Print Object
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print()
        {
            echo "<hr>";
            echo "<b>CDb Object</b><br>";
            echo "<table border='1' cellspacing='0' cellpadding='0'>";
            echo "<tr valign='top'><td><b>AccessMode:</b></td><td>" . $this->strAccessMode . "</td></tr>";

            if( $this->strAccessMode == "odbc" )
            {
                echo "<tr valign='top'><td><b>Dsn:</b></td><td>" . $this->strOdbcDsn . "</td></tr>";
            }
            else
            {
                echo "<tr valign='top'><td><b>Host:</b></td><td>" . $this->strHost . "</td></tr>";
                echo "<tr valign='top'><td><b>Db:</b></td><td>" . $this->strDb . "</td></tr>";
            }

            echo "<tr valign='top'><td><b>User:</b></td><td>" . $this->strUser . "</td></tr>";
            echo "<tr valign='top'><td><b>Password:</b></td><td>" . $this->strPassword . "</td></tr>";
            echo "</table>";
        }
    }
?>
