<?php
    /************************************************************************
        Class:          mct_CDbQuery
        Inheritance:    mct_CDbObject
        Description:    Query Object
    ************************************************************************/
    include_once("../inc/mct_general.inc.php");
    include_once("../inc/mct_func.inc.php");
    include_once("../inc/mct_CReturn.class.php");
    include_once("../inc/mct_CDbObject.class.php");
    include_once("../inc/mct_CDebug.class.php");

    class mct_CDbQuery extends mct_CDbObject
    {
        var $strQuery;          // Defines Sql-Query-String
        var $nRecordCount;      // Defines Record-Count after Execution

        /*-----------------------------------------------------------------------
            CONSTRUCTOR
        -----------------------------------------------------------------------*/
        function mct_CDbQuery()
        {
            // Initialize Properties
            $this->mct_init();
        }

        /*-----------------------------------------------------------------------
            Method:         Interface Functions
            Description:    get and set Methods for filling the Properties
        -----------------------------------------------------------------------*/
        function mct_getQuery()            { return $this->strQuery;     }
        function mct_getRecordCount()      { return $this->nRecordCount; }
        function mct_setQuery( $strValue, $bEmptyStr2Null = true )
        {
            if( is_string($strValue) )
            {
                $this->strQuery = $strValue;
                if( $bEmptyStr2Null )
                    $this->strQuery = str_replace("''", "null", $this->strQuery);
            }
        }

        /*-----------------------------------------------------------------------
            Method:         mct_init
            Description:    Initialize Properties
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_init()
        {
            parent::mct_init();
            $this->strQuery = "";
            $this->nRecordCount = -1;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_free
            Description:    Free Object and clean up
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_free()
        {
            // Free Parent
            parent::mct_free();
            // Set Object to NULL
            $this = null;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_execute
            Description:    Execute a Query
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         Boolean (true if succeeded, false if failed)
        -----------------------------------------------------------------------*/
        function mct_execute()
        {
            global $debug;
            $bReturn = false;

            // Reset Return-Object
            $this->objReturn->mct_free();
            $this->objReturn = new mct_CReturn();

            // check for ODBC-Mode
            if( $this->strAccessMode == "odbc" )
            {
                // Establish Connection if necessary
                if( ! is_resource($this->link) )
                   $this->link = @odbc_connect($this->strOdbcDsn, $this->strUser, $this->strPassword);

                // check again for resourceID
                if( is_resource($this->link) )
                {
                    // Execute Query and fill Result
                    if( $this->res = @odbc_exec($this->link, $this->strQuery) )
                    {
                        // Fill Return-Object
                        $this->objReturn->mct_setNumber(1);
                        $this->objReturn->mct_setDescription("Query ( " . $this->strQuery . " ) executed successfully");
                        $bReturn = true;

                        // Check if res is a Resource
                        if( is_resource($this->res) )
                        {
                            // Fill Count of affected rows
                            $this->nRecordCount = odbc_num_rows($this->res);
                            // when ODBC-Driver returns -1 on odbc_num_rows(), count it manualy!
                            if( $this->nRecordCount < 0 )
                            {
                                // Set Count to Zero
                                $this->nRecordCount = 0;
                                // Set internal_fetch_row_count to First Element
                                @odbc_fetch_row($this->res, 0);
                                // Count in while
                                while(@odbc_fetch_row($this->res)) $this->nRecordCount++;
                                // Set internal_fetch_row_count AGAIN to First Element
                                @odbc_fetch_row($this->res, 0);
                            }
                            // Fetch Row to Row-Object
                            $this->objRow = mct_odbc_fetch_object($this->res);
                        }
                        else
                        {
                            // Fill Return-Object
                            $this->objReturn->mct_setNumber(-4);
                            $this->objReturn->mct_setDescription("Did NOT get Resource-Identifier by odbc_exec()! Query ( "
                                . $this->strQuery . " )");
                        }
                    }
                    // Execution faild
                    else
                    {
                        // Fill Return-Object
                        $this->objReturn->mct_setNumber(-3);
                        $this->objReturn->mct_setDescription("Could not execute Query ( "
                            . $this->strQuery . " )<br><b>ODBC Error:</b> "
                            . odbc_error() . " - " . odbc_errormsg());
                    }
                }
                // Establishing of Connection faild
                else
                {
                    // Fill Return-Object
                    $this->objReturn->mct_setNumber(-1);
                    $this->objReturn->mct_setDescription("ODBC-Connection faild.");
                }
            }
            // NOT ODBC (MySQL)
            else
            {
                // Establish Connection
                if( $this->link = mysql_connect($this->strHost, $this->strUser, $this->strPassword) )
                {
                    // Select Database
                    if( mysql_select_db($this->strDb, $this->link) )
                    {
                        // Execute Query and fill Result
                        if( $this->res = mysql_query($this->strQuery, $this->link) )
                        {
                            // Fill Return-Object
                            $this->objReturn->mct_setNumber(1);
                            $this->objReturn->mct_setDescription("Query ( " . $this->strQuery . " ) executed successfully");
                            $bReturn = true;

                            // Check if res is a Resource (exeption: on Inserts, Updates, usw.)
                            if( is_resource($this->res) )
                            {
                                // Fetch Row to Row-Object
                                $this->objRow = mysql_fetch_object($this->res);
                                // Fill Count of affected rows
                                $this->nRecordCount = mysql_num_rows($this->res);
                            }
                            else
                            {
                                // res is not a Resource, its a counter
                                $this->nRecordCount = $this->res;
                            }
                        }
                        // Execution faild
                        else
                        {
                            // Fill Return-Object
                            $this->objReturn->mct_setNumber(-3);
                            $this->objReturn->mct_setDescription("Could not execute Query ( "
                                . $this->strQuery . " )<br><b>MySQL Error:</b> "
                                . mysql_errno() . " - " . mysql_error());
                        }
                    }
                    // Selection of Database faild
                    else
                    {
                        // Fill Return-Object
                        $this->objReturn->mct_setNumber(-2);
                        $this->objReturn->mct_setDescription("Could not select DB ( "
                            . $this->strDb . " )<br><b>MySQL Error:</b> "
                            . mysql_errno() . " - " . mysql_error());
                    }
                }
                // Establishing of Connection faild
                else
                {
                    // Fill Return-Object
                    $this->objReturn->mct_setNumber(-1);
                    $this->objReturn->mct_setDescription("MySQL-Connection faild.");
                }
            }

            if( ! $bReturn )
            {
                // Check for Debug-Mode and Debug-Object
                if( defined("_DEBUG_MODE_") && isset($debug) )
                {
                    // Add Error-Variable
                    $debug->mct_add_error("Error on mct_CDbQuery::mct_execute() - See the ERROR-Object on Stack", __FILE__, __LINE__);
                    $debug->mct_add_stack($this, "ERROR", __FILE__, __LINE__);
                }
            }
            // Check for Debug-Mode and Debug-Object
            if( defined("_DEBUG_MODE_") && isset($debug) )
            {
                // Add Query-Variable
                $debug->mct_add_query($this->strQuery, "Query " . "(Cnt:" . $this->nRecordCount . ")");

                // Check for Results by RecordCounter
                if( $this->nRecordCount > 0 )
                {
                    // Loop Query-Result
                    do
                    {
                        // Add to Debug-Object
                        $debug->mct_add_queryresult($this->objRow, $this->strQuery);
                    } while( $this->mct_getNext() );

                    // Reset Query to First Record
                    $this->mct_seek_first();
                }
            }

            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print
            Description:    Print Object
            ---------------------------------------------------------------------
            Parameter:      bAll        For Parent Object Information
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print( $bAll = true )
        {
            echo "<hr>";
            echo "<table border='1' cellspacing='0' cellpadding='0'><tr><td>";
            echo "<span style='color:red'><b>CQuery Object</b></span>";
            // Check if Print of Parent is desired
            if( $bAll ) parent::mct_print();
            echo "<hr>";
            echo "<b>CQuery Object</b><br>";
            echo "<table border='0'>";
            echo "<tr valign='top'><td><b>Query:</b></td><td>" . $this->strQuery . "</td></tr>";
            echo "<tr valign='top'><td><b>RecordCount:</b></td><td>" . $this->nRecordCount . "</td></tr>";
            echo "</table>";
            echo "</td></tr></table>";
        }
    }
?>
