<?php
    /************************************************************************
        Class:          mct_CDebug
        Inheritance:    non (Base class)
        Description:    Debug Object for collecting Debug-Information
    ************************************************************************/
    include_once("../inc/mct_general.inc.php");
    include_once("../inc/mct_func.inc.php");
    include_once("../inc/mct_CReturn.class.php");

    include_once("../inc/mct_CDbObject.class.php");
    include_once("../inc/mct_CDbQuery.class.php");

    include_once("../inc/mct_CFileCFG.class.php");
    include_once("../inc/mct_CConfigFile.class.php");
    include_once("../inc/mct_CInterface.class.php");
    include_once("../inc/mct_CCommunity.class.php");
    include_once("../inc/mct_CLocation.class.php");
    include_once("../inc/mct_CUser.class.php");
    include_once("../inc/mct_CTask.class.php");

    include_once("../inc/mct_CCfgHeaderSearch.class.php");
    include_once("../inc/mct_CCfgHeaderIntSearch.class.php");
    include_once("../inc/mct_CCfgIntSearch.class.php");
    include_once("../inc/mct_CSnmpSearch.class.php");

    class mct_CDebug
    {
        var $bProcessExtended;          // Defines to process and show Extended Options
        var $bProcessQueryResult;       // Defines to process and show all QueryResults
        var $bProcessSession;           // Defines to process and show all Sessionvariables
        var $bProcessGetPostCookie;     // Defines to process and show all GetPostCookie-Variables
        var $bProcessIWE;               // Defines to process and show all InfoWarningErrors

        var $arrInformation = array();  // Defines Information-Container
        var $arrWarning = array();      // Defines Warings-Container
        var $arrError = array();        // Defines Errors-Container
        var $arrStack = array();        // Defines Stack-Container
        var $arrQueries = array();      // Defines Queries-Container
        var $arrQueryResults = array(); // Defines QueryResults-Container

        var $arrHttpEnvVars = array();  // Defines HttpEnvironment-Container
        var $arrServer = array();       // Defines Servervariables-Container
        var $arrGet = array();          // Defines Get-Container
        var $arrPost = array();         // Defines Post-Container
        var $arrRequest = array();      // Defines Request-Container
        var $arrCookie = array();       // Defines Cookie-Container
        var $arrFiles = array();        // Defines File-Container

        var $arrDefinedVars = array();      // Defines DefinedVars-Container
        var $arrDefinedConstants = array(); // Defines DefinedConstants-Container
        var $arrIncludedFiles = array();    // Defines IncludedFiles-Container
        var $arrRequiredFiles = array();    // Defines RequiredFiles-Container

        var $arrDefinedFunctions = array(); // Defines DefinedFunctions-Container
        var $arrDeclearedClasses = array(); // Defines DeclearedClasses-Container
        var $arrLoadedExtensions = array(); // Defines LoadedExtensions-Container

        /*-----------------------------------------------------------------------
            CONSTRUCTOR
        -----------------------------------------------------------------------*/
        function mct_CDebug()
        {
            global $gArrMctIni;

            // Check Options from INI
            $this->bProcessExtended = false;
            $this->bProcessQueryResult = false;
            $this->bProcessSession = false;
            $this->bProcessGetPostCookie = false;
            $this->bProcessIWE = false;
            if( @$gArrMctIni["Debug"]["Extended"] )      $this->bProcessExtended = true;
            if( @$gArrMctIni["Debug"]["QueryResult"] )   $this->bProcessQueryResult = true;
            if( @$gArrMctIni["Debug"]["Session"] )       $this->bProcessSession = true;
            if( @$gArrMctIni["Debug"]["GetPostCookie"] ) $this->bProcessGetPostCookie = true;
            if( @$gArrMctIni["Debug"]["IWE"] )           $this->bProcessIWE = true;

            if( defined("_SAVE_MODE_") )
                $this->mct_add_warning("<b>Save-Mode is ON!</b>", __FILE__, __LINE__);
            if( defined("_TEST_MODE_") )
                $this->mct_add_warning("<b>Test-Mode is ON!</b>", __FILE__, __LINE__);

            // Init Object
            $this->mct_init();
        }

        /*-----------------------------------------------------------------------
            Method:         Interface Functions
            Description:    get and set Methods for filling the Properties
        -----------------------------------------------------------------------*/
        function mct_getProcessExtended()      { return $this->bProcessExtended;      }
        function mct_getProcessQueryResult()   { return $this->bProcessQueryResult;   }
        function mct_getProcessSession()       { return $this->bProcessSession;       }
        function mct_getProcessGetPostCookie() { return $this->bProcessGetPostCookie; }
        function mct_getProcessIWE()           { return $this->bProcessIWE;           }

        /*-----------------------------------------------------------------------
            Method:         mct_add_information
            Description:    Add Information to Debug-Object
            ---------------------------------------------------------------------
            Parameter:      value       Value to be added
                            file        File which calls this Method
                            line        Linenumber in calling File
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_add_information($value, $file, $line)
        {
            // check if to be processed
            if( $this->bProcessIWE && defined("_DEBUG_MODE_") )
                array_push($this->arrInformation, $value . " <font color='silver'>(" . basename($file) . " - " . $line . ")</font>");
        }

        /*-----------------------------------------------------------------------
            Method:         mct_add_warning
            Description:    Add Warnings to Debug-Object
            ---------------------------------------------------------------------
            Parameter:      value       Value to be added
                            file        File which calls this Method
                            line        Linenumber in calling File
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_add_warning($value, $file, $line)
        {
            // check if to be processed
            if( $this->bProcessIWE && defined("_DEBUG_MODE_") )
                array_push($this->arrWarning, $value . " <font color='silver'>(" . basename($file) . " - " . $line . ")</font>");
        }

        /*-----------------------------------------------------------------------
            Method:         mct_add_error
            Description:    Add Errors to Debug-Object
            ---------------------------------------------------------------------
            Parameter:      value       Value to be added
                            file        File which calls this Method
                            line        Linenumber in calling File
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_add_error($value, $file, $line)
        {
            // check if to be processed
            if( $this->bProcessIWE && defined("_DEBUG_MODE_") )
                array_push($this->arrError, $value . " <font color='silver'>(" . basename($file) . " - " . $line . ")</font>");
        }

        /*-----------------------------------------------------------------------
            Method:         mct_add_query
            Description:    Add Queries to Debug-Object
            ---------------------------------------------------------------------
            Parameter:      strQuery    Querystring to be added
                            strName     Name of Query
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_add_query($strQuery, $strName="[Unknown]")
        {
            if( defined("_DEBUG_MODE_") )
            {
                // Get VariableDump and Push Item into Array
                $arrItem = $this->mct_get_var_dump($strQuery, $strName);
                array_push($this->arrQueries, $arrItem);
            }
        }

        /*-----------------------------------------------------------------------
            Method:         mct_add_queryresult
            Description:    Add Queryresults to Debug-Object
            ---------------------------------------------------------------------
            Parameter:      objItem     Result-Object-Array
                            strQuery    Querystring to Determine which Results belongs to which Results
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_add_queryresult($objItem, $strQuery = "[Unknown]")
        {
            // Check for Processing QueryResults
            if( $this->bProcessQueryResult && defined("_DEBUG_MODE_") )
            {
                // Convert Object to Array
                $arrItem = get_object_vars($objItem);
                $arrItem['__Query'] = $strQuery;
                // Set EXPLICIT to Array because of array_values, and array_keys
                settype($arrItem, "array");

                // Add to Array
                array_push($this->arrQueryResults, $arrItem);
            }
        }

        /*-----------------------------------------------------------------------
            Method:         mct_add_stack
            Description:    Add Stack-Objects to Debug-Object
            ---------------------------------------------------------------------
            Parameter:      vItem       Variant-Object-Item
                            strName     Name of Object
                            file        File which calls this Method
                            line        Linenumber in calling File
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_add_stack($vItem, $strName="[Unknown]", $file, $line)
        {
            if( defined("_DEBUG_MODE_") )
            {
                // Get VariableDump and Push Item into Array
                $arrItem = $this->mct_get_var_dump($vItem, $strName, $file, $line);
                array_push($this->arrStack, $arrItem);
            }
        }

        /*-----------------------------------------------------------------------
            Method:         mct_dump_it
            Description:    Saving site variables for Debug-Object
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_dump_it()
        {
            //if debug modus is ON
            if( defined("_DEBUG_MODE_") )
            {
                 // check if to be processed
                if( $this->bProcessExtended )
                {
                    // get several Environment Variables
                    $this->arrHttpEnvVars["SERVER_SOFTWARE"]   = getenv("SERVER_SOFTWARE");
                    $this->arrHttpEnvVars["SERVER_NAME"]       = getenv("SERVER_NAME");
                    $this->arrHttpEnvVars["GATEWAY_INTERFACE"] = getenv("GATEWAY_INTERFACE");
                    $this->arrHttpEnvVars["SERVER_PROTOCOL"]   = getenv("SERVER_PROTOCOL");
                    $this->arrHttpEnvVars["SERVER_PORT"]       = getenv("SERVER_PORT");
                    $this->arrHttpEnvVars["REQUEST_METHOD"]    = getenv("REQUEST_METHOD");
                    $this->arrHttpEnvVars["PATH_INFO"]         = getenv("PATH_INFO");
                    $this->arrHttpEnvVars["PATH_TRANSLATED"]   = getenv("PATH_TRANSLATED");
                    $this->arrHttpEnvVars["SCRIPT_NAME"]       = getenv("SCRIPT_NAME");
                    $this->arrHttpEnvVars["QUERY_STRING"]      = getenv("QUERY_STRING");
                    $this->arrHttpEnvVars["REMOTE_HOST"]       = getenv("REMOTE_HOST");
                    $this->arrHttpEnvVars["REMOTE_ADDR"]       = getenv("REMOTE_ADDR");
                    $this->arrHttpEnvVars["AUTH_TYPE"]         = getenv("AUTH_TYPE");
                    $this->arrHttpEnvVars["REMOTE_USER"]       = getenv("REMOTE_USER");
                    $this->arrHttpEnvVars["REMOTE_IDENT"]      = getenv("REMOTE_IDENT");
                    $this->arrHttpEnvVars["CONTENT_TYPE"]      = getenv("CONTENT_TYPE");
                    $this->arrHttpEnvVars["CONTENT_LENGTH"]    = getenv("CONTENT_LENGTH");
                    $this->arrHttpEnvVars["HTTP_ACCEPT"]       = getenv("HTTP_ACCEPT");
                    $this->arrHttpEnvVars["HTTP_USER_AGENT"]   = getenv("HTTP_USER_AGENT");

                    $this->arrServer = $_SERVER;
                    $this->arrFiles = $_FILES;

                    $this->arrDefinedVars       = get_defined_vars();
                    $this->arrDefinedConstants  = get_defined_constants();
                    $this->arrIncludedFiles     = get_included_files();
                    $this->arrRequiredFiles     = get_required_files();
                    $this->arrDefinedFunctions  = array_reverse(get_defined_functions());
                    $this->arrLoadedExtensions  = get_loaded_extensions();

                    $arrClasses = get_declared_classes();
                    foreach( $arrClasses as $item )
                        $this->arrDeclearedClasses[$item] = get_class_methods($item);
                }

                 // check if to be processed
                if( $this->bProcessGetPostCookie )
                {
                    $this->arrGet       = $_GET;
                    $this->arrPost      = $_POST;
                    $this->arrCookie    = $_COOKIE;
                }
                $this->arrRequest = $_REQUEST;

                // set Debug_Object for debug-site
                $_SESSION["Debug_Object"] = $this;
            }
        }

        /*-----------------------------------------------------------------------
            Method:         mct_load_it
            Description:    Writes JavaScript to calling Page, so Debugframe will be loaded
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_load_it()
        {
            if( defined("_DEBUG_MODE_") )
                echo "<script language='JavaScript'>parent.frames['Debugframe'].location.href='../src/debug.php';</script>";
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print_httpenvvars
            Description:    Print Content of Property in HTML
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print_httpenvvars()
        {
            echo "<h4>HTTP_ENV_VARS</h4>";
            $this->mct_parse_array($this->arrHttpEnvVars);
            echo "<br><br>";
            echo "<h2>Loaded Extensions</h2>";
            $this->mct_parse_array($this->arrLoadedExtensions);
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print_session
            Description:    Print Content of Property in HTML
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print_session()
        {
            echo "<h4>_SESSION</h4>";
            $this->mct_parse_array($_SESSION);
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print_server
            Description:    Print Content of Property in HTML
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print_server()
        {
            echo "<h4>_SERVER</h4>";
            $this->mct_parse_array($this->arrServer);
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print_get
            Description:    Print Content of Property in HTML
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print_get()
        {
            echo "<h4>_GET</h4>";
            $this->mct_parse_array($this->arrGet);
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print_post
            Description:    Print Content of Property in HTML
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print_post()
        {
            echo "<h4>_POST</h4>";
            $this->mct_parse_array($this->arrPost);
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print_request
            Description:    Print Content of Property in HTML
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print_request()
        {
            echo "<h4>_REQUEST</h4>";
            $this->mct_parse_array($this->arrRequest);
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print_cookie
            Description:    Print Content of Property in HTML
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print_cookie()
        {
            echo "<h4>_COOKIE</h4>";
            $this->mct_parse_array($this->arrCookie);
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print_files
            Description:    Print Content of Property in HTML
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print_files()
        {
            echo "<h4>_FILES</h4>";
            $this->mct_parse_array($this->arrFiles);
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print_extended
            Description:    Print Content of Property in HTML
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print_extended()
        {
            echo "<h4>ALL Defined Variables</h4>";
            $this->mct_parse_array($this->arrDefinedVars);
            echo "<br><br>";
            echo "<h4>ALL Defined Constants</h4>";
            $this->mct_parse_array($this->arrDefinedConstants);
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print_iwe
            Description:    Print Content of Property in HTML
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print_iwe()
        {
            echo "<ul>";
            echo "<h2>Information</h2>";
            foreach( $this->arrInformation as $Item )
                echo "<li>" . $Item . "</li>";
            echo "</ul>";

            echo "<ul>";
            echo "<h2>Warnings</h2>";
            foreach( $this->arrWarning as $Item )
                echo "<li>" . $Item . "</li>";
            echo "</ul>";

            echo "<ul>";
            echo "<h2>Errors</h2>";
            foreach( $this->arrError as $Item )
                echo "<li>" . $Item . "</li>";
            echo "</ul>";
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print_includes
            Description:    Print Content of Property in HTML
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print_includes()
        {
            echo "<ul>";
            echo "<h2>Included Files</h2>";
            foreach( $this->arrIncludedFiles as $Item )
                echo "<li>" . $Item . "</li>";
            echo "</ul>";

            echo "<ul>";
            echo "<h2>Required Files</h2>";
            foreach( $this->arrRequiredFiles as $Item )
                echo "<li>" . $Item . "</li>";
            echo "</ul>";
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print_definedfunctions
            Description:    Print Content of Property in HTML
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print_definedfunctions()
        {
            echo "<h4>Defined Functions</h4>";
            $this->mct_parse_array($this->arrDefinedFunctions);
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print_declearedclasses
            Description:    Print Content of Property in HTML
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print_declearedclasses()
        {
            echo "<h4>Decleared Classes</h4>";
            $this->mct_parse_array($this->arrDeclearedClasses);
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print_queries
            Description:    Print Content of Property in HTML
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print_queries()
        {
            echo "<h2>Queries</h2>";
            echo "<table width='100%' cellspacing='0' cellpadding='3'>";
            echo "<tr bgcolor='#8F8F8F'>";
            echo "<td width='10%'><b>Name</b></td>";
            echo "<td width='50%'><b>Value</b></td>";
            echo "<td width='10%'><b>Length</b></td>";
            echo "</tr>";
            $bColor = true;
            foreach( $this->arrQueries as $arrItem )
            {
                if( $bColor ) $strColor="#EFEFEF";
                else  $strColor="#CFCFCF";

                echo "<tr valign='top' bgcolor='" . $strColor . "'>";
                echo "<td>" . $arrItem['Name'] . "</td>";

                echo "<td>";
                if( is_array($arrItem['Value']) )
                    $this->mct_parse_array($arrItem['Value']);
                elseif( is_object($arrItem['Value']) )
                {
                    if( is_a($arrItem['Value'], "mct_cdebug") ) echo "DEBUG-OBJECT";
                    else $this->mct_parse_array(get_object_vars($arrItem['Value']));
                }
                elseif( gettype($arrItem['Value']) == "object" )
                {
                    echo "<b><font color='red'>ATTENTION: Probably __PHP_Incomplete_Class Object !!!</font></b><br>";
                    print_r($arrItem['Value']);
                }
                else echo htmlentities($arrItem['Value']);
                echo "</td>";

                echo "<td>";
                print_r($arrItem['Length']);
                echo "</td>";
                echo "</tr>";

                $bColor = !$bColor;
            }
            echo "</table>";
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print_queryresults
            Description:    Print Content of Property in HTML
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print_queryresults()
        {
            echo "<h4>Query-Results</h4>";
            $bColor = true;
            $bSetHeadLines = true;
            $strLastQuery = "";
            $bFirstLoop = true;
            foreach( $this->arrQueryResults as $arrItem )
            {
                // Get Values and Keys
                $arrVar = array_values($arrItem);
                $arrKey = array_keys($arrItem);

                // Change Color when Query changed (-> other Result is comming)
                if( $arrItem['__Query'] != $strLastQuery )
                {
                    $strLastQuery = $arrItem['__Query'];
                    $bColor = !$bColor;
                    $bSetHeadLines = true;
                }

                // Set Colors
                if( $bColor ) $strColor="#EFEFEF";
                else  $strColor="#CFCFCF";

                // check for setting HeadLines
                if( $bSetHeadLines )
                {
                    // Write End-Tag of last Table when not at the very first beginning
                    if( ! $bFirstLoop ) echo "</table>";
                    // Write new Table
                    echo "<table width='100%' cellspacing='0' cellpadding='3'>";
                    echo "<tr bgcolor='#8F8F8F'>";
                    for( $i=0; $i < count($arrKey); $i++ )
                    {
                        // Cut Internal Variable __Query in Array
                        if( $arrKey[$i] != "__Query" )
                            echo "<td><b>" . $arrKey[$i] . "</b></td>";
                    }
                    echo "</tr>";
                    $bSetHeadLines = false;
                }

                // Write DataLines
                echo "<tr valign='top' bgcolor='" . $strColor . "'>";
                for( $i=0; $i < count($arrVar)-1; $i++ )  // count()-1 for cutting Internal Variable __Query
                    echo "<td>" . htmlentities($arrVar[$i]) . "</td>";
                echo "</tr>";

                // Set First Loop to false
                $bFirstLoop = false;
            }
            // Last Table
            echo "</table>";
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print_stack
            Description:    Print Content of Property in HTML
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print_stack()
        {
            echo "<h2>Stack</h2>";
            echo "<table width='100%' cellspacing='0' cellpadding='3'>";
            echo "<tr bgcolor='#8F8F8F'>";
            echo "<td width='10%'><b>Name</b></td>";
            echo "<td width='10%'><b>Type</b></td>";
            echo "<td width='*'><b>Value</b></td>";
            echo "<td width='5%'><b>Length</b></td>";
            echo "<td width='10%'><b>File</b></td>";
            echo "<td width='5%'><b>Line</b></td>";
            echo "</tr>";
            $bColor = true;
            foreach( $this->arrStack as $arrItem )
            {
                if( $bColor ) $strColor="#EFEFEF";
                else  $strColor="#CFCFCF";

                echo "<tr valign='top' bgcolor='" . $strColor . "'>";
                echo "<td>";
                if( $arrItem['Name'] == "ERROR" ) echo "<font color='red'><b>";
                echo $arrItem['Name'];
                if( $arrItem['Name'] == "ERROR" ) echo "</b></font>";
                echo "</td>";

                echo "<td>";
                echo $arrItem['Type'];
                echo "</td>";

                echo "<td>";
                if( is_array($arrItem['Value']) )
                    $this->mct_parse_array($arrItem['Value']);
                elseif( is_object($arrItem['Value']) )
                {
                    if( is_a($arrItem['Value'], "mct_cdebug") ) echo "DEBUG-OBJECT";
                    else $this->mct_parse_array(get_object_vars($arrItem['Value']));
                }
                elseif( gettype($arrItem['Value']) == "object" )
                {
                    echo "<b><font color='red'>ATTENTION: Probably __PHP_Incomplete_Class Object !!!</font></b><br>";
                    print_r($arrItem['Value']);
                }
                else echo htmlentities($arrItem['Value']);
                echo "</td>";

                echo "<td>";
                print_r($arrItem['Length']);
                echo "</td>";

                echo "<td>";
                if( strlen($arrItem['File']) <= 0 ) echo "&nbsp;";
                else print_r(basename($arrItem['File']));
                echo "</td>";

                echo "<td>";
                if( $arrItem['Line'] <= 0 ) echo "&nbsp;";
                else print_r($arrItem['Line']);
                echo "</td>";
                echo "</tr>";

                $bColor = !$bColor;
            }
            echo "</table>";
        }

        /*-----------------------------------------------------------------------
            Method:         mct_parse_array
            Description:    Parse an Array to HTML
            ---------------------------------------------------------------------
            Parameter:      arr         Array to be parsed
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_parse_array($arr)
        {
            $icnt = count($arr);
            $arrkey = array_keys($arr);
            $arrval = array_values($arr);

            echo "<table width='100%' cellspacing='0' cellpadding='3'>";
            echo "<tr bgcolor='#8F8F8F'>";
            echo "<td width='20%'><b>Name</b></td>";
            echo "<td width='10%'><b>Type</b></td>";
            echo "<td width='70%'><b>Value</b></td>";
            echo "</tr>";
            $bColor = true;
            for( $i=0; $i < $icnt; $i++ )
            {
                if( $bColor ) $strColor="#EFEFEF";
                else $strColor="#CFCFCF";

                echo "<tr valign='top' bgcolor='" . $strColor . "'>";
                echo "<td>" . $arrkey[$i] . "</td>";

                echo "<td>";
                echo gettype($arrval[$i]);
                echo "</td>";

                echo "<td>";
                if( is_array($arrval[$i]) )
                    $this->mct_parse_array($arrval[$i]);
                elseif( is_object($arrval[$i]) )
                {
                    if( is_a($arrval[$i], "mct_cdebug") ) echo "DEBUG-OBJECT";
                    else $this->mct_parse_array(get_object_vars($arrval[$i]));
                }
                elseif( gettype($arrval[$i]) == "object" )
                {
                    echo "<b><font color='red'>ATTENTION: Probably __PHP_Incomplete_Class Object !!!</font></b><br>";
                    print_r($arrval[$i]);
                }
                else echo htmlentities($arrval[$i]);
                echo "</td>";
                echo "</tr>";

                $bColor = !$bColor;
            }
            echo "</table>";
        }

        /*-----------------------------------------------------------------------
            Method:         mct_free
            Description:    Clear the Object
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_free()
        {
            //dump it first
            $this->mct_dump_it();

            // free all array-items
            unset($this->arrInformation);
            unset($this->arrWarning);
            unset($this->arrError);
            unset($this->arrStack);
            unset($this->arrQueries);
            unset($this->arrQueryResults);

            unset($this->arrHttpEnvVars);
            unset($this->arrServer);
            unset($this->arrGet);
            unset($this->arrPost);
            unset($this->arrRequest);
            unset($this->arrCookie);
            unset($this->arrFiles);

            unset($this->arrDefinedVars);
            unset($this->arrDefinedConstants);
            unset($this->arrIncludedFiles);
            unset($this->arrRequiredFiles);
            unset($this->arrDefinedFunctions);
            unset($this->arrLoadedExtensions);

            // Reset Session to NULL
            $_SESSION["Debug_Object"] = null;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_init
            Description:    Initialize Properties
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_init()
        {
            unset($_SESSION["Debug_Object"]);
            $_SESSION["Debug_Object"] = null;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_get_var_dump
            Description:    Create VariableDump in a Array
            ---------------------------------------------------------------------
            Parameter:      vItem       Item-Data
                            strName     Name of Item
                            file        File which calls this Method
                            line        Linenumber in calling File
            ---------------------------------------------------------------------
            Return:         Array       Filled VarDump
        -----------------------------------------------------------------------*/
        function mct_get_var_dump($vItem, $strName, $file = "", $line = -1)
        {
            $strType = "";
            $iLen = -1;

            if( strlen($strName) <= 0 ) $strName = "[Unknown]";
            $strType = gettype($vItem);

            if( empty($vItem) && (is_string($vItem) || is_array($vItem) || is_object($vItem))  )
                $vValue = "[Empty]";
            else $vValue = $vItem;

            if( is_string($vItem) )
            {
                $iLen = strlen($vItem);
                $vValue = "'" . $vValue . "'";
            }
            if( is_bool($vItem) )
            {
                if( $vItem ) $vValue = "true";
                else $vValue= "false";
            }

            $arrItem['Name'] = $strName;
            $arrItem['Type'] = $strType;
            $arrItem['Value'] = $vValue;
            $arrItem['Length'] = $iLen;
            $arrItem['File'] = $file;
            $arrItem['Line'] = $line;
            return $arrItem;
        }
    }
?>