<?php
    /************************************************************************
        Class:          mct_CFileCFG <abstract>
        Inheritance:    non (Base class)
        Description:    CFG Object <abstract>
    ************************************************************************/
    include_once("../inc/mct_general.inc.php");
    include_once("../inc/mct_func.inc.php");
    include_once("../inc/mct_CReturn.class.php");
    include_once("../inc/mct_CDebug.class.php");
    include_once("../inc/mct_CDbQuery.class.php");

    class mct_CFileCFG
    {
        var $nId;       // Defines Object ID
        var $strName;   // Defines Object Name

        /*-----------------------------------------------------------------------
            NO CONSTRUCTOR ! Class is ABSTRACT
        -----------------------------------------------------------------------*/

        /*-----------------------------------------------------------------------
            Method:         Interface Functions
            Description:    get and set Methods for filling the Properties
        -----------------------------------------------------------------------*/
        function mct_getId()              { return $this->nId;     }
        function mct_getName()            { return $this->strName; }
        function mct_setName( $strValue ) { if( is_string($strValue) ) $this->strName = $strValue; }

        /*-----------------------------------------------------------------------
            Method:         mct_getNewID
            Description:    Get a new Primary ID Key from a Table
            ---------------------------------------------------------------------
            Parameter:      strTable         Table with a Field 'ID'
            ---------------------------------------------------------------------
            Return:         Integer          New ID
        -----------------------------------------------------------------------*/
        function mct_getNewID( $strTable )
        {
            global $debug;

            $nNewId = -1;
            $objNewID = new mct_CDbQuery;
            $objNewID->mct_setQuery("SELECT COUNT(*) AS Cnt FROM " . $strTable);
            // Execute Query to see if there is 1 Row at MINIMUM (so that Select Max dont crashes)
            if( $objNewID->mct_execute() )
            {
                // check Count because SELECT MAX on a Table with NO Records will CRASH
                if( $objNewID->objRow->Cnt > 0 )
                {
                    $objNewID->mct_free();
                    $objNewID = new mct_CDbQuery;
                    $objNewID->mct_setQuery("SELECT MAX(`ID`) as MaxId FROM " . $strTable);
                    // Execute Query
                    if( ! $objNewID->mct_execute() )
                    {
                        // Error happend
                        $objNewID->objReturn->mct_print();
                    }
                    else
                    {
                        $nNewId = $objNewID->objRow->MaxId;
                        if( $nNewId == NULL ) $nNewId = 0;
                        $nNewId++;
                    }
                }
                else $nNewId = 1;
            }
            else
            {
                if( defined("_DEBUG_MODE_") && isset($debug) ) $debug->mct_add_stack($objNewID, "ERROR", __FILE__, __LINE__);
                $objNewID->objReturn->mct_print();
            }
            $objNewID->mct_free();
            return $nNewId;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_deletefromdb
            Description:    Delete a Record from a Table
            ---------------------------------------------------------------------
            Parameter:      nId              Record ID
                            strTable         Table for delection
            ---------------------------------------------------------------------
            Return:         Boolean          true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_deletefromdb( $nId = -1, $strTable = "" )
        {
            global $debug;

            $bReturn = false;
            // Check Parameter
            if( $nId > -1 && strlen($strTable) > 0 )
            {
                $objDel = new mct_CDbQuery;
                // Generate Query
                $objDel->mct_setQuery("DELETE FROM " . $strTable . " WHERE `ID`=". $nId);
                // Execute Query
                if( ! $objDel->mct_execute() )
                {
                    // Error happend
                    $objDel->objReturn->mct_print();
                }
                else
                {
                    // Deletion successful
                    $bReturn = true;
                }
                $objDel->mct_free();
            }
            if( !$bReturn && defined("_DEBUG_MODE_") && isset($debug) ) $debug->mct_add_stack($this, "ERROR", __FILE__, __LINE__);
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_init
            Description:    Initialize Properties
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_init()
        {
            $this->nId = -1;
            $this->strName = "";
        }

        /*-----------------------------------------------------------------------
            Method:         mct_free
            Description:    Clean Up Object
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_free()
        {
            // DO NOT SET Object to NULL!
            // Class is ABSTRACT and can't be an Object
            // Just Init its Properties
            $this->mct_init();
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print
            Description:    Print Object
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print()
        {
            echo "<hr>";
            echo "<b>CFileCFG Object</b><br>";
            echo "<table border='0' cellspacing='0' cellpadding='0'>";
            echo "<tr valign='top'><td><b>Id:</b></td><td>" . $this->nId . "</td></tr>";
            echo "<tr valign='top'><td><b>Name:</b></td><td>" . $this->strName . "</td></tr>";
            echo "</table>";
        }
        /*-----------------------------------------------------------------------
            Method:         mct_isvalid
            Description:    Checks if Object is valid
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         Boolean            true if valid, else false
        -----------------------------------------------------------------------*/
        function mct_isvalid()
        {
            if( $this->nId != -1 ) return true;
            else return false;
        }
    }
?>
