<?php
    /************************************************************************
        Class:          mct_CCommunity
        Inheritance:    mct_CFileCFG
        Description:    Community Object
    ************************************************************************/
    include_once("../inc/mct_general.inc.php");
    include_once("../inc/mct_func.inc.php");
    include_once("../inc/mct_CFileCFG.class.php");
    include_once("../inc/mct_CDebug.class.php");
    include_once("../inc/mct_CDbQuery.class.php");

    class mct_CLocation extends mct_CFileCFG
    {
        var $strDescription;        // Defines Description
        var $strType;               // Defines Type in Words
        var $nType;                 // Defines Type as Number
        var $nParentLocationID;     // Defines its ParentLocationID when existing

        /*-----------------------------------------------------------------------
            CONSTRUCTOR
        -----------------------------------------------------------------------*/
        function mct_CLocation($nType)
        {
            global $debug;

            // Initialize Properties
            $this->mct_init();
            $this->nType = $nType;
            if( $nType === 1 ) $this->strType = "global";
            elseif( $nType === 2 ) $this->strType = "";
            elseif( $nType === 3 ) $this->strType = "sub";
            else
            {
                $err = "Type of Location unknown! Allowed are 1, 2 and 3!";
                echo $err;
                if( defined("_DEBUG_MODE_") && isset($debug) )
                    $debug->mct_add_error("mct_CLocation::Constructor(): " . $err, __FILE__, __LINE__);
            }
        }

        /*-----------------------------------------------------------------------
            Method:         Interface Functions
            Description:    get and set Methods for filling the Properties
        -----------------------------------------------------------------------*/
        function mct_getType()                   { return $this->strType; }
        function mct_getTypeId()                 { return $this->nType; }
        function mct_getDescription()            { return $this->strDescription; }
        function mct_getParentLocationID()       { return $this->nParentLocationID; }

        function mct_setDescription( $strValue )    { if( is_string($strValue) ) $this->strDescription = $strValue; }
        function mct_setParentLocationID( $nValue ) { if( is_int($nValue) ) $this->nParentLocationID = $nValue; }

        /*-----------------------------------------------------------------------
            Method:         mct_init
            Description:    Initialize Properties
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_init()
        {
            parent::mct_init();
            $this->strDescription = "";
            $this->strType = "";
            $this->nType = -1;
            $this->nParentLocationID = null;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_free
            Description:    Free result and clean up
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_free()
        {
            // Free Parent
            parent::mct_free();
            // Set Object to NULL
            $this = null;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_writedb
            Description:    Inserts or Updates Object to Database
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         Boolean            true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_writedb()
        {
            global $debug;

            $bReturn = false;

            // Create Query-Object
            $objDB = new mct_CDbQuery;

            // Check if Object has an ID
            if( $this->nId == -1 )
            {
                // Get New ID on tconfigfile
                $this->nId = $this->mct_getNewID("t" . $this->strType . "location");

                // Create INSERT Query
                $qry = "INSERT INTO t" . $this->strType . "location(`ID`, `Name`, `Description`";
                if( $this->nType == 2 ) $qry .= ", `fkGlobalLocationID`";
                elseif( $this->nType == 3 ) $qry .= ", `fkLocationID`";
                $qry .= ") VALUES(";
                $qry .= $this->nId;
                $qry .= ", '" . $objDB->mct_DBStr($this->strName) . "'";
                $qry .= ", '" . $objDB->mct_DBStr($this->strDescription) . "'";
                if( $this->nType == 2 || $this->nType == 3)
                    $qry .= ", " . $this->nParentLocationID;
                $qry .= ")";
                $objDB->mct_setQuery($qry);

                // Execute Query
                if( ! $objDB->mct_execute() )
                {
                    // Error happend
                    $objDB->objReturn->mct_print();
                }
                else $bReturn = true;
            }
            // Object has ID, so Update it!
            else
            {
                // Create UPDATE Query
                $qry =  "UPDATE t" . $this->strType . "location SET ";
                $qry .= " `Name` = '" . $objDB->mct_DBStr($this->strName) . "'";
                $qry .= ", `Description` = '" . $objDB->mct_DBStr($this->strDescription) . "'";
                if( $this->nType == 2 ) $qry .= ", `fkGlobalLocationID` = " . $this->nParentLocationID;
                elseif( $this->nType == 3 ) $qry .= ", `fkLocationID` = " . $this->nParentLocationID;
                $qry .= " WHERE `ID` = " . $this->nId;

                $objDB->mct_setQuery($qry);

                // Execute Query
                if( ! $objDB->mct_execute() )
                {
                    // Error happend
                    $objDB->objReturn->mct_print();
                }
                else $bReturn = true;
            }
            // Free Object
            $objDB->mct_free();
            if( !$bReturn && defined("_DEBUG_MODE_") && isset($debug) ) $debug->mct_add_stack($this, "ERROR", __FILE__, __LINE__);
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_getfromdb
            Description:    Get Object from Database
            ---------------------------------------------------------------------
            Parameter:      nId            Integer of Record ID
            ---------------------------------------------------------------------
            Return:         Boolean        true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_getfromdb( $nId = -1 )
        {
            global $debug;

            $bReturn = false;
            $objDB = new mct_CDbQuery;
            // Create Query
            $objDB->strQuery = "SELECT * FROM t" . $this->strType . "location WHERE `ID` = " . $nId;
            // Execute Query
            if( ! $objDB->mct_execute() || $objDB->mct_getRecordCount() == 0 )
            {
                // Error happend OR no rows returned
                $objDB->objReturn->mct_print();
            }
            else
            {
                // Fill Object with values
                $this->nId = (int)$objDB->objRow->ID;
                $this->strName = $objDB->objRow->Name;
                $this->strDescription = $objDB->objRow->Description;
                if( $this->nType == 2 ) $this->nParentLocationID = (int)$objDB->objRow->fkGlobalLocationID;
                elseif( $this->nType == 3 ) $this->nParentLocationID = (int)$objDB->objRow->fkLocationID;
                $bReturn = true;
            }
            $objDB->mct_free();
            if( !$bReturn && defined("_DEBUG_MODE_") && isset($debug) ) $debug->mct_add_stack($this, "ERROR", __FILE__, __LINE__);
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_deletefromdb
            Description:    Delete a Record from a Table
            ---------------------------------------------------------------------
            Return:         Boolean          true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_deletefromdb()
        {
            global $debug;

            $bReturn = false;
            if( $this->nId > -1 )
            {
                $bReturn = parent::mct_deletefromdb($this->nId, "t" . $this->strType . "location");
            }
            if( !$bReturn && defined("_DEBUG_MODE_") && isset($debug) ) $debug->mct_add_stack($this, "ERROR", __FILE__, __LINE__);
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print
            Description:    Print Object
            ---------------------------------------------------------------------
            Parameter:      $bAll            For Parent Object Information
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print( $bAll = true )
        {
            echo "<hr>";
            echo "<table border='1' cellspacing='0' cellpadding='0'><tr><td>";
            echo "<span style='color:red'><b>CLocation Object</b></span>";
            // Check if Print of Parent is desired
            if( $bAll ) parent::mct_print();
            echo "<hr>";
            echo "<b>CLocation Object</b><br>";
            echo "<table border='0'>";
            echo "<tr valign='top'><td><b>Description:</b></td><td>" . $this->strDescription . "</td></tr>";
            if( $this->nType == 2 || $this->nType == 3)
            {
                echo "<tr valign='top'><td><b>ParentLocationID:</b></td><td>" . $this->nParentLocationID . "</td></tr>";
            }
            if( strlen($this->strType) == 0 )
            {
                echo "<tr valign='top'><td><b>Type:</b></td><td>" . $this->nType . " - normal</td></tr>";
            }
            else
            {
                echo "<tr valign='top'><td><b>Type:</b></td><td>" . $this->nType . " - " . $this->strType . "</td></tr>";
            }
            echo "</table>";
            echo "</td></tr></table>";
        }
    }
?>
