<?php
    /************************************************************************
        Class:          mct_CSnmpSearch
        Description:    Object for SNMP Infos
    ************************************************************************/
    include_once("../inc/mct_general.inc.php");
    include_once("../inc/mct_func.inc.php");

    class mct_CSnmpSearch
    {
        // Set-Variabeln (Allgemein)
        var $strSnmpHostname;
        var $strSnmpCommunity;
        var $strSnmpPort;
        var $IndexViewStatus;
        var $ifIndex;
        var $SnmpIfIndex;
        var $SnmpIfDescr;
        var $SnmpIfType;
        var $SnmpIfSpeed = array();
        var $SnmpIfAdminStatus;
        var $SnmpIfOperStatus;
        var $SnmpIfLastChange;

        /*-----------------------------------------------------------------------
            CONSTRUCTOR
        -----------------------------------------------------------------------*/
        function mct_CSnmpSearch()
        {
            // Initialize Properties
            $this->mct_init();
        }

        /*-----------------------------------------------------------------------
            Method:         mct_checkExtension
            Description:    Check if needed Extesions are Loaded by PHP
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         $bReturn        true = loaded, false = not loaded
        -----------------------------------------------------------------------*/
        function mct_checkExtension()
        {
            $bReturn = mct_ask_extension("snmp");
            if( ! $bReturn  )
            {
                echo "Die bentigte PHP-Erweiterung <b>php_snmp.dll</b> f&uuml;r SNMP wurde von PHP nicht geladen.";
                echo "<br>Im <b>PHP.ini</b> muss diese Extension aktiviert werden und sich im definierten <b>extension_dir</b> befinden!";
                echo "<br><br>Sollte diese Distribution die DLL nicht beinhalten, kann sie unter <a target='_blank' href='http://www.php.net'>www.php.net</a> heruntergeladen werden.<p>";
            }
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_init
            Description:    Init Properties of Object
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_init()
        {
            $this->strSnmpHostname = "";
            $this->strSnmpCommunity = "";
            $this->strSnmpPort = "";
            $this->IndexViewStatus = "";
            $this->ifIndex = "";
            $this->SnmpIfIndex = "";
            $this->SnmpIfDescr = "";
            $this->SnmpIfType = "";
            $this->SnmpIfSpeed = array();
            $this->SnmpIfAdminStatus = "";
            $this->SnmpIfOperStatus = "";
            $this->SnmpIfLastChange = "";
        }

        /*-----------------------------------------------------------------------
            Method:         mct_free
            Description:    Free result and clean up
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_free()
        {
            // Set Object to NULL
            $this = null;
        }

        /*-----------------------------------------------------------------------
            Method:         SNMP Functions
            Description:    get and set Methods for read SNMP Infos
        -----------------------------------------------------------------------*/
        function mct_setSnmpHostname($strSnmpHostname)   { if( is_string($strSnmpHostname) ) $this->strSnmpHostname = $strSnmpHostname;   }
        function mct_setSnmpCommunity($strSnmpCommunity) { if( is_string($strSnmpCommunity) ) $this->strSnmpCommunity = $strSnmpCommunity;}
        function mct_setSnmpPort($strSnmpPort)           { if( is_string($strSnmpPort) ) $this->strSnmpPort = $strSnmpPort;               }
        // View-Funktionen
        function mct_viewSnmpIndex($IndexViewStatus)             { if( $IndexViewStatus == "checked")      { return "checked"; }}
        function mct_viewSnmpDescr($DescrViewStatus)             { if( $DescrViewStatus == "checked")      { return "checked"; }}
        function mct_viewSnmpType($TypeViewStatus)               { if( $TypeViewStatus == "checked")       { return "checked"; }}
        function mct_viewSnmpSpeed($SpeedViewStatus)             { if( $SpeedViewStatus == "checked")      { return "checked"; }}
        function mct_viewSnmpAdminStatus($AdminStatusViewStatus) { if( $AdminStatusViewStatus == "checked"){ return "checked"; }}
        function mct_viewSnmpOperStatus($OperStatusViewStatus)   { if( $OperStatusViewStatus == "checked") { return "checked"; }}
        function mct_viewSnmpLastChange($LastChangeViewStatus)   { if( $LastChangeViewStatus == "checked") { return "checked"; }}
        // Get-Funktionen
        function mct_getIfIndex()           { return $this->ifIndex;           }
        function mct_getSnmpIfIndex()       { return $this->SnmpIfIndex;       }
        function mct_getSnmpIfDescr()       { return $this->SnmpIfDescr;       }
        function mct_getSnmpIfType()        { return $this->SnmpIfType;        }
        function mct_getSnmpIfSpeed()       { return $this->SnmpIfSpeed;       }
        function mct_getSnmpIfAdminStatus() { return $this->SnmpIfAdminStatus; }
        function mct_getSnmpIfOperStatus()  { return $this->SnmpIfOperStatus;  }
        function mct_getSnmpIfLastChange()  { return $this->SnmpIfLastChange;  }

        /*-----------------------------------------------------------------------
            Method:         mct_get_SnmpInfo
            Description:    holt Werte aus der MIB
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         $nReturn        1 = success, -1 = failed
        -----------------------------------------------------------------------*/
        function mct_getSnmpInfo()
         {
            global $debug;
            global $gArrMctIni;

            $nReturn = -1;

            if( defined("_DEBUG_MODE_") && isset($debug) && !defined("_MCT_CSNMPSEARCH_GETSNMPINFO_FUNCTION_") )
            {
                // set define, that the Information only appears one time in the Debugger and not on each call!
                define("_MCT_CSNMPSEARCH_GETSNMPINFO_FUNCTION_",  true);
                $debug->mct_add_information("mct_CSnmpSearch::mct_getSnmpInfo() reduced Error Output by PHP @", __FILE__, __LINE__);
            }

            if( $this->mct_checkExtension() )
            {
                // QuickPrint setzen, damit keine EXTRA Infos ausgegeben werden
                @snmp_set_quick_print(true);

                $target = $this->strSnmpHostname . ":" . $this->strSnmpPort; // Zusammensetzen Hostname und Port
                $timeout = (int)$gArrMctIni["Snmp"]["Timeout"];

                if ( $this->ifIndex = @snmpwalkoid($target, $this->strSnmpCommunity, $gArrMctIni["Snmp"]["Index"], $timeout)) // OID's aus der MIB holen
                {
                    // Rcksetzen auf 1. Element, OID des akt. Elements, nchstes Element
                    for( @reset($this->ifIndex); $oid = @key($this->ifIndex); @next($this->ifIndex) )
                    {
                        $this->SnmpIfIndex = $this->ifIndex[$oid];

                        $var = $gArrMctIni["Snmp"]["Descr"] . "." . $this->SnmpIfIndex;
                        $this->SnmpIfDescr[$this->SnmpIfIndex] = @snmpget($target, $this->strSnmpCommunity, $var, $timeout);

                        $var = $gArrMctIni["Snmp"]["Type"] . "." . $this->SnmpIfIndex;
                        $this->SnmpIfType[$this->SnmpIfIndex] = @snmpget($target, $this->strSnmpCommunity, $var, $timeout);

                        $var = $gArrMctIni["Snmp"]["Speed"] . "." . $this->SnmpIfIndex;
                        $this->SnmpIfSpeed[$this->SnmpIfIndex] = @snmpget($target, $this->strSnmpCommunity, $var, $timeout);

                        $var = $gArrMctIni["Snmp"]["AdminStatus"] . "." . $this->SnmpIfIndex;
                        $this->SnmpIfAdminStatus[$this->SnmpIfIndex] = @snmpget($target, $this->strSnmpCommunity, $var, $timeout);

                        $var = $gArrMctIni["Snmp"]["OperStatus"] . "." . $this->SnmpIfIndex;
                        $this->SnmpIfOperStatus[$this->SnmpIfIndex] = @snmpget($target, $this->strSnmpCommunity, $var, $timeout);

                        $var = $gArrMctIni["Snmp"]["LastChange"] . "." . $this->SnmpIfIndex;
                        $this->SnmpIfLastChange[$this->SnmpIfIndex] = @snmpget($target, $this->strSnmpCommunity, $var, $timeout);
                    }
                    $nReturn = 1;
                }
            }
            return $nReturn;
         }
    }// Ende der Klasse
