<?php
    /************************************************************************
        Class:          mct_CTask
        Inheritance:    mct_CFileCFG.class.php
        Description:    Class for administrating the MCT Window Tasks on the Server
    ************************************************************************/
    include_once("../inc/mct_general.inc.php");
    include_once("../inc/mct_func.inc.php");
    include_once("../inc/mct_CFileCFG.class.php");
    include_once("../inc/mct_CDbQuery.class.php");

    class mct_CTask extends mct_CFileCFG
    {
        var $strStarttime;      // Defines Starttime of Task
        var $strCreator;        // Defines Creator of Task
        var $strComment;        // Defines Taskcomment
        var $strLogname;        // Defines Name of Logfile
        var $strLogpfad;        // Defines Path of Logfile
        var $nLogact;           // Defines Use of log-function
        var $strPerlpfad;       // Defines Path of Perl-Exe
        var $strMrtgpfad;       // Defines Path of MRTG-Script
        var $strTasktyp;        // Defines Type of Task
        var $nIntervalday;      // Defines Interval of Day
        var $nIntervalweek;     // Defines Interval of Week
        var $strCfgname;        // Defines Name of ConfigFile
        var $strCfgpfad;        // Defines Path of ConfigFile
        var $strPrgname;        // Defines Name of Programm
        var $strPrgpfad;        // Defines Path of Programm
        var $strParameter;      // Defines Parameters
        var $strWorkpath;       // Defines Workpath
        var $strOdw;            // Defines 'once', 'daily' or 'weekly'
        var $strWday;           // Defines Weekday
        var $strAccount;        // Defines Account
        var $strPwd;            // Defines Password for Account

        /*-----------------------------------------------------------------------
            CONSTRUCTOR
        -----------------------------------------------------------------------*/
        function mct_CTask()
        {
            // Initialize Properties
            $this->mct_init();
        }

        /*-----------------------------------------------------------------------
            Method:         mct_checkExtension
            Description:    Check if needed Extesions are Loaded by PHP
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         Boolean            true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_checkExtension()
        {
            $bReturn = mct_ask_extension("mcrypt");
            if( ! $bReturn  )
            {
                echo "Die bentigte PHP-Erweiterung <b>php_mcrypt.dll</b> f&uuml;r den Crypt-Algorithmus wurde von PHP nicht geladen.";
                echo "<br>Im <b>PHP.ini</b> muss diese Extension aktiviert werden und sich im definierten <b>extension_dir</b> befinden!";
                echo "<br><br>Sollte diese Distribution die DLL nicht beinhalten, kann sie unter <a target='_blank' href='http://www.php.net'>www.php.net</a> heruntergeladen werden.<p>";
            }
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_init
            Description:    Initialize Properties
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_init()
        {
            parent::mct_init();
            $this->strStarttime     = null;
            $this->strCreator       = null;
            $this->strComment       = null;
            $this->strParameter     = null;
            $this->strWorkpath      = null;
            $this->strOdw           = null;
            $this->strWday          = null;
            $this->strLogname       = null;
            $this->strLogpfad       = null;
            $this->strPerlpfad      = null;
            $this->strMrtgpfad      = null;
            $this->strTasktyp       = null;
            $this->nIntervalday     = -1;
            $this->nIntervalweek    = -1;
            $this->strCfgname       = null;
            $this->strCfgpfad       = null;
            $this->strPrgname       = null;
            $this->strPrgpfad       = null;
            $this->strAccount       = null;
            $this->strPwd           = null;
            $this->nLogact          = -1;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_free
            Description:    Clean Up Object
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_free()
        {
            // Free Parent
            parent::mct_free();
            // Set Object to NULL
            $this = null;
        }

        /*-----------------------------------------------------------------------
            Method:         Task Functions
            Description:    get and set Methods for filling the Properties
        -----------------------------------------------------------------------*/
        function mct_setAccount($strValue)      { if( is_string($strValue) ) $this->strAccount = $strValue;      }
        function mct_setPwd($strValue)
        {
            if( $this->mct_checkExtension() )
            {
                if( is_string($strValue) && strlen($strValue) > 0 )
                {
                    $key = "MCT_Crpytkey";
                    $size = mcrypt_get_iv_size(MCRYPT_3DES, MCRYPT_MODE_ECB);
                    $iv = mcrypt_create_iv($size, MCRYPT_RAND);
                    $cryptstr = mcrypt_ecb(MCRYPT_3DES, $key, $strValue, MCRYPT_ENCRYPT, $iv );
                    $this->strPwd = mct_prepare_queryvalue($cryptstr);
                }
            }
        }
        function mct_setStarttime($strValue)    { if( is_string($strValue) ) $this->strStarttime = $strValue;    }
        function mct_setCreator($strValue)      { if( is_string($strValue) ) $this->strCreator = $strValue;      }
        function mct_setComment($strValue)      { if( is_string($strValue) ) $this->strComment = $strValue;      }
        function mct_setParameter($strValue)
        {
            if( is_string($strValue) )
                $this->strParameter = $strValue;
        }
        function mct_setWorkpath($strValue)
        {
            if( is_string($strValue) )
                $this->strWorkpath = mct_ConvertPath($strValue, true);
        }
        function mct_setOdw($strValue)          { if( is_string($strValue) ) $this->strOdw = $strValue;          }
        function mct_setWday($strValue)         { if( is_string($strValue) ) $this->strWday = $strValue;         }
        function mct_setLogname($strValue)      { if( is_string($strValue) ) $this->strLogname = $strValue;      }
        function mct_setLogpfad($strValue)
        {
            if( is_string($strValue) )
                $this->strLogpfad = mct_ConvertPath($strValue, true);
        }
        function mct_setLogact($nValue)         { if( is_int   ($nValue)   ) $this->nLogact = $nValue;           }
        function mct_setPerlpfad($strValue)
        {
            if( is_string($strValue) )
                $this->strPerlpfad = mct_ConvertPath($strValue, false);
        }
        function mct_setMrtgpfad($strValue)
        {
            if( is_string($strValue) )
                $this->strMrtgpfad = mct_ConvertPath($strValue, false);
        }
        function mct_setTasktyp($strValue)      { if( is_string($strValue) ) $this->strTasktyp = $strValue;      }
        function mct_setIntervalday($nValue)    { if( is_int   ($nValue)   ) $this->nIntervalday = $nValue;      }
        function mct_setIntervalweek($nValue)   { if( is_int   ($nValue)   ) $this->nIntervalweek = $nValue;     }
        function mct_setCfgname($strValue)      { if( is_string($strValue) ) $this->strCfgname = $strValue;      }
        function mct_setCfgpfad($strValue)
        {
            if( is_string($strValue) )
                $this->strCfgpfad = mct_ConvertPath($strValue, true);
        }
        function mct_setPrgname($strValue)      { if( is_string($strValue) ) $this->strPrgname = $strValue;      }
        function mct_setPrgpfad($strValue)
        {
            if( is_string($strValue) )
                $this->strPrgpfad = mct_ConvertPath($strValue, true);
        }

        function mct_getAccount()            { return $this->strAccount;    }
        function mct_getPwd()
        {
            $valReturn = false;
            if( $this->mct_checkExtension() && strlen($this->strPwd) > 0 )
            {
                $key = "MCT_Crpytkey";
                $size = mcrypt_get_iv_size(MCRYPT_3DES, MCRYPT_MODE_ECB);
                $iv = mcrypt_create_iv($size, MCRYPT_RAND);
                $valReturn = mcrypt_ecb(MCRYPT_3DES, $key, $this->strPwd, MCRYPT_DECRYPT, $iv );
            }
            return $valReturn;
        }
        function mct_getStarttime()          { return $this->strStarttime;  }
        function mct_getCreator()            { return $this->strCreator;    }
        function mct_getComment()            { return $this->strComment;    }
        function mct_getParameter()          { return $this->strParameter;  }
        function mct_getWorkpath()           { return $this->strWorkpath;   }
        function mct_getOdw()                { return $this->strOdw;        }
        function mct_getWday()               { return $this->strWday;       }
        function mct_getLogname()            { return $this->strLogname;    }
        function mct_getLogpfad()            { return $this->strLogpfad;    }
        function mct_getLogact()             { return $this->nLogact;       }
        function mct_getPerlpfad()           { return $this->strPerlpfad;   }
        function mct_getMrtgpfad()           { return $this->strMrtgpfad;   }
        function mct_getTasktyp()            { return $this->strTasktyp;    }
        function mct_getIntervalday()        { return $this->nIntervalday;  }
        function mct_getIntervalweek()       { return $this->nIntervalweek; }
        function mct_getCfgname()            { return $this->strCfgname;    }
        function mct_getCfgpfad()            { return $this->strCfgpfad;    }
        function mct_getPrgname()            { return $this->strPrgname;    }
        function mct_getPrgpfad()            { return $this->strPrgpfad;    }

        /*-----------------------------------------------------------------------
            Method:         mct_addtask
            Description:    Add Windows-Task
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         Boolean            true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_addtask()
        {
            global $gArrMctIni;
            global $gCRLF;
            global $debug;
            $bReturn = false;

            $exe       = "";
            $date      = "";
            $time      = "";
            $parameter = "";
            $iteration = "";
            $timerange = "";
            $strwdays  = "";

            // check for Save-Mode
            if( defined("_SAVE_MODE_") )
            {
                echo "<p><b>Warning:</b> Action can NOT proceed because SAVE-MODE is ON!</p>";
                return $bReturn;
            }

            // Taskausfhrung bestimmen
            if($this->mct_getOdw() == "weekly")
            {
                //Tage in Zahlen umwandeln
                $iwdays = explode(",", $this->strWday);
                if( in_array("mo", $iwdays) ) $mo = "1,"; else $mo = "";
                if( in_array("di", $iwdays) ) $di = "2,"; else $di = "";
                if( in_array("mi", $iwdays) ) $mi = "3,"; else $mi = "";
                if( in_array("do", $iwdays) ) $do = "4,"; else $do = "";
                if( in_array("fr", $iwdays) ) $fr = "5,"; else $fr = "";
                if( in_array("sa", $iwdays) ) $sa = "6,"; else $sa = "";
                if( in_array("so", $iwdays) ) $so = "7,"; else $so = "";
                $strwdays2 = $mo.$di.$mi.$do.$fr.$sa.$so;
                $strwdays = substr($strwdays2, 0, strlen($strwdays2) - 1);
            }
            //Auszufhrendes Prg bestimmen
            if($this->strTasktyp == "mrtgtask")
            {
                if ( $this->nLogact > 0 and $this->strLogpfad != "" and $this->strLogname != "")
                {
                    $logbatpfad = "\"" . $gArrMctIni["Task"]["mctLog"] . "\" ";
                    $exe = $logbatpfad;
                    $parameter = "\"\"" . $this->strPerlpfad . "\""." ".
                                 "\"" . $this->strMrtgpfad . "\""." ".
                                 "\"" . $this->strCfgpfad . $this->strCfgname."\""." ".
                                 "\"" . $this->mct_getLogpfad() . $this->mct_getLogname()."\"\"";
                }
                else
                {
                    $exe = $this->strPerlpfad;
                    $parameter = $this->strMrtgpfad." ".$this->strCfgpfad . $this->strCfgname;
                }
            }
            else
            {
                $exe = $this->strPrgpfad.$this->strPrgname;
                $parameter = $this->mct_getParameter();
            }
            //Datum bestimmen -> Umwandlung auf amerikanische Eingabe
            $date2 = substr($this->strStarttime, 0, 10);
            $date2 = explode("-",$date2);
            //print_r($date2);
            $year = $date2[2];
            $month = $date2[1];
            $day = $date2[0];
            $date = $year."-".$month."-".$day;
            // Zeit bestimmen
            $time2 = substr($this->strStarttime, 11, 8);
            $time2 = explode(":",$time2);
            //print_r($time2);
            $hour = $time2[0];
            $minute = $time2[1];
            $time = $hour.":".$minute;
            //Timeiteration
            $iteration = "";
            if($this->strOdw == "daily")
            {
                $iteration = "";
                if($this->nIntervalday > 0 )
                {
                    $intIterationDay = 1440 / $this->nIntervalday;
                    $iteration = ($intIterationDay - 1);
                    $timerange = $this->nIntervalday;
                }
            }
            else if($this->strOdw == "weekly")
            {
                $iteration = "";
                if ($this->nIntervalweek > 0 )
                {
                    $intIterationWeek = 1440 / $this->nIntervalweek;
                    $iteration = ($intIterationWeek - 1);
                    $timerange = $this->nIntervalweek;
                }
            }

            $arrDefFile = array();
            $arrDefFile[0]  = "[MCT_TASK]";
            $arrDefFile[1]  = "[HEADER]";
            $arrDefFile[2]  = "action=add";
            $arrDefFile[3]  = "taskname=".$gArrMctIni["Task"]["Taskprefix"].$this->mct_getName();
            $arrDefFile[4]  = "delafterexec=true";
            $arrDefFile[5]  = "[ACTION_ADD]";
            $arrDefFile[6]  = "type=".$this->mct_getOdw();
            $arrDefFile[7]  = "executable=".$exe;
            $arrDefFile[8]  = "date=".$date;
            $arrDefFile[9]  = "time=".$time;
            $arrDefFile[10] = "account=".$this->mct_getAccount();
            $arrDefFile[11] = "pwd=".$this->mct_getPwd();
            $arrDefFile[12] = "creator=".$this->mct_getCreator();
            $arrDefFile[13] = "comment=".$this->mct_getComment();
            $arrDefFile[14] = "parameter=".$parameter;
            $arrDefFile[15] = "workpath=".$this->mct_getWorkpath();
            $arrDefFile[16] = "unique=false";
            $arrDefFile[17] = "timeiteration=".$iteration; // Teilungsdifferenz (1440 Min : Interval)
            $arrDefFile[18] = "interval=1"; // fixer Eintrag
            $arrDefFile[19] = "timerange=".$timerange; // Interval Angabe auf Webseite
            $arrDefFile[20] = "days=".$strwdays;

            // Creates a temporary File in Temp-Directory
            $tmp = tempnam("/tmp", "MCT");
            mct_write_file($tmp, $arrDefFile);
            $taskexepfad = "\"" . $gArrMctIni["Task"]["mctTask"] . "\" ";
            $execString = $taskexepfad." -def=" . $tmp;
            $arrRes = array();
            $iret = $this->mct_batExecute($execString, $arrRes);
            if( $iret == 0 )
                $bReturn = true;
            else
            {
                echo "<h4>Output mct_task.exe:</h4>";
                for($i=0; $i < count($arrRes); $i++)
                    echo $arrRes[$i] . "<br>";
            }
            if( defined("_DEBUG_MODE_") && isset($debug) )
                $debug->mct_add_stack($arrRes, "Output mct_task.exe", __FILE__, __LINE__);
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_deltask
            Description:    Delete Windows-Task
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         Boolean            true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_deltask($taskname)
        {
            global $gArrMctIni;
            global $gCRLF;
            $bReturn = false;

            // check for Save-Mode
            if( defined("_SAVE_MODE_") )
            {
                echo "<p><b>Warning:</b> Action can NOT proceed because SAVE-MODE is ON!</p>";
                return $bReturn;
            }

            $arrDefFile = array();
            $arrDefFile[0] = "[MCT_TASK]";
            $arrDefFile[1] = "[HEADER]";
            $arrDefFile[2] = "action=del";
            $arrDefFile[3] = "taskname=mct_task_".$taskname;
            $arrDefFile[4] = "delafterexec=true";
            // Creates a temporary File in Temp-Directory
            $tmp = tempnam("/tmp", "MCT");
            mct_write_file($tmp, $arrDefFile);
            $taskexepfad = "\"" . $gArrMctIni["Task"]["mctTask"] . "\" ";
            $execString = $taskexepfad." -def=" . $tmp;
            $arrRes = array();
            $iret = $this->mct_batExecute($execString, $arrRes);
            if( $iret == 0 )
                $bReturn = true;
            else
            {
                echo "<h4>Output mct_task.exe:</h4>";
                for($i=0; $i < count($arrRes); $i++)
                    echo $arrRes[$i] . "<br>";
            }
            if( defined("_DEBUG_MODE_") && isset($debug) )
                $debug->mct_add_stack($arrRes, "Output mct_task.exe", __FILE__, __LINE__);
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_batExecute
            Description:    Executes a String in a BAT-File
            ---------------------------------------------------------------------
            Parameter:      $command    Execution Command
                            $result     Output-Parameter for Result-Lines of Execution
            ---------------------------------------------------------------------
            Return:         Integer       Batch-Return-Value of exec-function
        -----------------------------------------------------------------------*/
        function mct_batExecute($command, &$result)
        {
            global $debug;

            // check for Save-Mode
            if( defined("_SAVE_MODE_") )
            {
                echo "<p><b>Warning:</b> Action can NOT proceed because SAVE-MODE is ON!</p>";
                return 0;   //Error
            }

            if( defined("_DEBUG_MODE_") && isset($debug) )
                $debug->mct_add_stack($command, "batExecute", __FILE__, __LINE__);
            // Creates a temporary File in Temp-Directory
            $tmpbat = tempnam("/tmp", "MCT");
            // Delete File to have only the name
            unlink($tmpbat);
            // Add Ending BAT
            $tmpbat .= ".bat";
            if( defined("_DEBUG_MODE_") && isset($debug) )
                $debug->mct_add_information("Temp-BAT-File <b>" .$tmpbat . "</b> is used for special execution and will be deleted after usage!", __FILE__, __LINE__);
            // Create and Open BAT-File
            $fp = fopen($tmpbat, "w");
            // Write echo off to file to be able only to see the real Output
            fwrite($fp, "@echo off\n");
            // Write Command to File
            fwrite($fp, $command); // or whatever you wanna run
            // Close File
            fclose($fp);
            // Execute BAT-File
            exec($tmpbat, $result, $iret);
            // Delete BAT-File
            unlink($tmpbat);
            // Check Returnvalue
            if( $iret != 0 )
            {
                if( defined("_DEBUG_MODE_") && isset($debug) )
                {
                    $debug->mct_add_error("Returnvalue on exec() in <b>mct_CTask::mct_batExecute()</b> indicates an Error. See <b>DOSCommand</b> and <b>DOSResult</b> on Stack.", __FILE__, __LINE__);
                    $debug->mct_add_stack($command, "DOSCommand", __FILE__, __LINE__);
                    $debug->mct_add_stack($result, "DOSResult", __FILE__, __LINE__);
                }
            }
            // Return Result
            return $iret;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_get_taskstatus
            Description:    Get Status of Windows-Task (Active, Inactive)
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         Boolean     true = Active, false = Inactive
        -----------------------------------------------------------------------*/
        function mct_getTaskstatus($taskname)
        {
            global $gArrMctIni;
            global $gCRLF;
            global $debug;
            $bTaskStatus = false; //Taskstatus auf false setzen

            // check for Save-Mode
            if( defined("_SAVE_MODE_") )
            {
                //echo "<p><b>Warning:</b> Action can NOT proceed because SAVE-MODE is ON!</p>";
                return $bTaskStatus;
            }

            $taskexepfad = "\"" . $gArrMctIni["Task"]["mctTask"] . "\" "; // Angabe des Pfades von mct_task.exe
            $objActTasks = new mct_CDbQuery; // Abfrage an DB, welche Tasks eingetragen sind
            $objActTasks->mct_setQuery("SELECT `ID`,`Name` FROM tTask where `Name` = '$taskname' ORDER BY `Name`");
            if( $objActTasks->mct_execute() == false ) //Abfrage ausfhren
            {
                $objActTasks->objReturn->mct_print(); //Falls Abfrage fehl schlug
                return false;
            }
            else // Wenn Abfrage erfolgreich war
            {
                $arrDefFile = array(); // Parameter fr Def-File in Array abfllen
                $arrDefFile[0] = "[MCT_TASK]";
                $arrDefFile[1] = "[HEADER]";
                $arrDefFile[2] = "action=list";
                $arrDefFile[3] = "taskname=mct_task_".$taskname;
                $arrDefFile[4] = "delafterexec=true";
                // Creates a temporary File in Temp-Directory
                $tmp = tempnam("/tmp", "MCT");
                mct_write_file($tmp, $arrDefFile);
                $taskexepfad = "\"" . $gArrMctIni["Task"]["mctTask"] . "\" "; // Pfad von Task exe
                $execString = $taskexepfad." -def=" . $tmp; // Zusammensetzen des Exec-Strings
                $arrRes = array();
                $iret = $this->mct_batExecute($execString, $arrRes); // Ausfhren des Exec-Strings und R-Wert abfllen
                if( $iret != 0 ) // Bei Fehler Ausgabe
                {
                    echo "<h4>Output mct_task.exe:</h4>";
                    for($i=0; $i < count($arrRes); $i++)
                        echo $arrRes[$i] . "<br>";
                    $bTaskStatus = false;
                }
                else
                {
                    while( list($key, $val) = each ($arrRes) )
                    {
                        if( $bTaskStatus = stristr($val, "mct_task_".$taskname) )
                            break;
                    }
                }
                if( defined("_DEBUG_MODE_") && isset($debug) )
                    $debug->mct_add_stack($arrRes, "Output mct_task.exe", __FILE__, __LINE__);
            }
            return $bTaskStatus;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_writedb
            Description:    Insert or Updates Object to Database
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         Boolean            true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_writedb()
        {
            $bReturn = false;

            // Create Query-Object
            $objDB = new mct_CDbQuery;

            // Check if Object has an ID
            if( $this->nId == -1 )
            {
                // Get New ID on tconfigfile
                $this->nId = $this->mct_getNewID('tTask');

                // Create INSERT Query
                $objDB->mct_setQuery("INSERT INTO tTask(`ID`, `Name`, `Starttime`, `Creator`, `Comment`, `Parameter`,"
                                     ." `Workpath`, `Odw`, `Wday`, `Logname`, `Logpfad`, `Perlpfad`, `Mrtgpfad`,"
                                     ." `Tasktyp`, `Intervalday`, `Intervalweek`, `Cfgname`, `Cfgpfad`, `Prgname`,"
                                     ." `Prgpfad`, `Account`, `Pwd`, `logact`)"
                    ." VALUES("
                    . $this->nId
                    .", '"  . $objDB->mct_DBStr($this->strName) . "'"
                    .", '"  . $this->strStarttime   . "'"
                    .", '"  . $this->strCreator     . "'"
                    .", '"  . $objDB->mct_DBStr($this->strComment) . "'"
                    .", '"  . $this->strParameter   . "'"
                    .", '"  . $this->strWorkpath    . "'"
                    .", '"  . $this->strOdw         . "'"
                    .", '"  . $this->strWday        . "'"
                    .", '"  . $this->strLogname     . "'"
                    .", '"  . $this->strLogpfad     . "'"
                    .", '"  . $this->strPerlpfad    . "'"
                    .", '"  . $this->strMrtgpfad    . "'"
                    .", '"  . $this->strTasktyp     . "'"
                    .", "   . $this->nIntervalday
                    .", "   . $this->nIntervalweek
                    .", '"  . $this->strCfgname     . "'"
                    .", '"  . $this->strCfgpfad     . "'"
                    .", '"  . $this->strPrgname     . "'"
                    .", '"  . $this->strPrgpfad     . "'"
                    .", '"  . $this->strAccount     . "'"
                    .", '"  . $this->strPwd         . "'"
                    .", "   . $this->nLogact
                    .")", false);

                // Execute Query
                if( ! $objDB->mct_execute() )
                {
                    // Error happend
                    $objDB->objReturn->mct_print();
                }
                else $bReturn = true;
            }
            // Object has ID, so Update it!
            else
            {
                // Create UPDATE Query
                $objDB->mct_setQuery("UPDATE tTask SET "
                    ."  `Name`='"        . $objDB->mct_DBStr($this->strName) . "', "
                    ."  `Account`='"     . $this->strAccount     . "', "
                    ."  `Pwd`='"         . $this->strPwd         . "', "
                    ."  `Starttime`='"   . $this->strStarttime   . "', "
                    ."  `Creator`='"     . $this->strCreator     . "', "
                    ."  `Comment`='"     . $objDB->mct_DBStr($this->strComment) . "', "
                    ."  `Parameter`='"   . $this->strParameter   . "', "
                    ."  `Workpath`='"    . $this->strWorkpath    . "', "
                    ."  `Odw`='"         . $this->strOdw         . "', "
                    ."  `Wday`='"        . $this->strWday        . "', "
                    ."  `Logname`='"     . $this->strLogname     . "', "
                    ."  `Logpfad`='"     . $this->strLogpfad     . "', "
                    ."  `Perlpfad`='"    . $this->strPerlpfad    . "', "
                    ."  `Mrtgpfad`='"    . $this->strMrtgpfad    . "', "
                    ."  `Tasktyp`='"     . $this->strTasktyp     . "', "
                    ."  `Intervalday`="  . $this->nIntervalday    . ", "
                    ."  `Intervalweek`=" . $this->nIntervalweek   . ", "
                    ."  `Cfgname`='"     . $this->strCfgname     . "', "
                    ."  `CfgPfad`='"     . $this->strCfgpfad     . "', "
                    ."  `Prgname`='"     . $this->strPrgname     . "', "
                    ."  `Prgpfad`='"     . $this->strPrgpfad     . "', "
                    ."  `logact`="       . $this->nLogact
                    ." WHERE `ID`="      . $this->nId, false);

                // Execute Query
                if( ! $objDB->mct_execute() )
                {
                    // Error happend
                    $objDB->objReturn->mct_print();
                }
                else $bReturn = true;
            }
            // Free Object
            $objDB->mct_free();
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_getfromdb
            Description:    Get Object from Database
            ---------------------------------------------------------------------
            Parameter:      nId            Integer of Record ID
            ---------------------------------------------------------------------
            Return:         Boolean        true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_getfromdb( $nId = -1 )
        {
            $bReturn = false;
            $objDB = new mct_CDbQuery;
            // Create Query
            $objDB->strQuery = "SELECT * FROM tTask WHERE `ID`=" . $nId;
            // Execute Query
            if( ! $objDB->mct_execute() )
            {
                // Error happend
                $objDB->objReturn->mct_print();
            }
            elseif( $objDB->mct_getRecordCount() == 0 )
            {
                // Print DB-Object
                // <p>$objDB->mct_print(false);
            }
            else
            {
                // Fill Object with values
                $this->nId              = (int)$objDB->objRow->ID;
                $this->strName          = $objDB->objRow->Name;
                $this->strAccount       = $objDB->objRow->Account;
                $this->strPwd           = $objDB->objRow->Pwd;
                $this->strStarttime     = $objDB->objRow->Starttime;
                $this->strCreator       = $objDB->objRow->Creator;
                $this->strComment       = $objDB->objRow->Comment;
                $this->strParameter     = $objDB->objRow->Parameter;
                $this->strWorkpath      = $objDB->objRow->Workpath;
                $this->strOdw           = $objDB->objRow->Odw;
                $this->strWday          = $objDB->objRow->Wday;
                $this->strLogname       = $objDB->objRow->Logname;
                $this->strLogpfad       = $objDB->objRow->Logpfad;
                $this->nLogact          = $objDB->objRow->logact;
                $this->strPerlpfad      = $objDB->objRow->Perlpfad;
                $this->strMrtgpfad      = $objDB->objRow->Mrtgpfad;
                $this->strTasktyp       = $objDB->objRow->Tasktyp;
                $this->nIntervalday     = (int)$objDB->objRow->Intervalday;
                $this->nIntervalweek    = (int)$objDB->objRow->Intervalweek;
                $this->strCfgname       = $objDB->objRow->Cfgname;
                $this->strCfgpfad       = $objDB->objRow->Cfgpfad;
                $this->strPrgname       = $objDB->objRow->Prgname;
                $this->strPrgpfad       = $objDB->objRow->Prgpfad;
                $bReturn = true;
            }
            $objDB->mct_free();
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_getfromdb
            Description:    Get Object from Database
            ---------------------------------------------------------------------
            Parameter:      nId            Integer of Record ID
            ---------------------------------------------------------------------
            Return:         Boolean        true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_getfromdb_byname( $strName = "" )
        {
            $bReturn = false;
            if( $strName == "" )
                return false;

            $objDB = new mct_CDbQuery;
            // Create Query
            $objDB->strQuery = "SELECT * FROM tTask WHERE `Name`='" . $strName . "'";
            // Execute Query
            if( ! $objDB->mct_execute() )
            {
                // Error happend
                $objDB->objReturn->mct_print();
            }
            elseif( $objDB->mct_getRecordCount() == 0 )
            {
                // Print DB-Object
                //<p> $objDB->mct_print(false);
            }
            else
            {
                // Fill Object with values
                $this->nId =            (int)$objDB->objRow->ID;
                $this->strName =        $objDB->objRow->Name;
                $this->strAccount =     $objDB->objRow->Account;
                $this->strPwd =         $objDB->objRow->Pwd;
                $this->strStarttime =   $objDB->objRow->Starttime;
                $this->strCreator =     $objDB->objRow->Creator;
                $this->strComment =     $objDB->objRow->Comment;
                $this->strParameter =   $objDB->objRow->Parameter;
                $this->strWorkpath =    $objDB->objRow->Workpath;
                $this->strOdw =         $objDB->objRow->Odw;
                $this->strWday =        $objDB->objRow->Wday;
                $this->strLogname =     $objDB->objRow->Logname;
                $this->strLogpfad =     $objDB->objRow->Logpfad;
                $this->strPerlpfad =    $objDB->objRow->Perlpfad;
                $this->strMrtgpfad =    $objDB->objRow->Mrtgpfad;
                $this->strTasktyp =     $objDB->objRow->Tasktyp;
                $this->nIntervalday =   (int)$objDB->objRow->Intervalday;
                $this->nIntervalweek =  (int)$objDB->objRow->Intervalweek;
                $this->strCfgname =     $objDB->objRow->Cfgname;
                $this->strCfgpfad =     $objDB->objRow->Cfgpfad;
                $this->strPrgname =     $objDB->objRow->Prgname;
                $this->strPrgpfad =     $objDB->objRow->Prgpfad;
                $bReturn = true;
            }
            $objDB->mct_free();
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_deletefromdb
            Description:    Delete a Record from a Table
            ---------------------------------------------------------------------
            Return:         Boolean          true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_deletefromdb()
        {
            $bReturn = false;
            if( $this->nId > -1 )
            {
                $bReturn = parent::mct_deletefromdb($this->nId, "tTask");
            }
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print
            Description:    Print Object
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print()
        {
            echo "<hr>";
            echo "<table border='1' cellspacing='0' cellpadding='0'><tr><td>";
            echo "<span style='color:red'><b>CTask Object</b></span>";
            echo "<tr valign='top'><td><b>Name:</b></td><td>" . $this->strName . "</td></tr>";
            echo "<tr valign='top'><td><b>Account:</b></td><td>" . $this->strAccount . "</td></tr>";
            echo "<tr valign='top'><td><b>Passwort:</b></td><td>" . $this->strPwd . "</td></tr>";
            echo "<tr valign='top'><td><b>Datum / Zeit:</b></td><td>" . $this->strStarttime . "</td></tr>";
            echo "<tr valign='top'><td><b>Tasktyp:</b></td><td>" . $this->strTasktyp . "</td></tr>";
            echo "<tr valign='top'><td><b>CFG Name:</b></td><td>" . $this->strCfgname . "</td></tr>";
            echo "<tr valign='top'><td><b>CFG Pfad:</b></td><td>" . $this->strCfgpfad . "</td></tr>";
            echo "<tr valign='top'><td><b>Perl Pfad:</b></td><td>" . $this->strPerlpfad . "</td></tr>";
            echo "<tr valign='top'><td><b>MRTG Pfad:</b></td><td>" . $this->strMrtgpfad . "</td></tr>";
            echo "<tr valign='top'><td><b>Logname:</b></td><td>" . $this->strLogname . "</td></tr>";
            echo "<tr valign='top'><td><b>Logpfad:</b></td><td>" . $this->strLogpfad . "</td></tr>";
            echo "<tr valign='top'><td><b>Log:</b></td><td>" . $this->nLogact . "</td></tr>";
            echo "<tr valign='top'><td><b>Ausfhrung:</b></td><td>" . $this->strOdw . "</td></tr>";
            echo "<tr valign='top'><td><b>Interval Tag:</b></td><td>" . $this->nIntervalday . "</td></tr>";
            echo "<tr valign='top'><td><b>Interval Woche:</b></td><td>" . $this->nIntervalweek . "</td></tr>";
            echo "<tr valign='top'><td><b>Wochentage:</b></td><td>" . $this->strWday . "</td></tr>";
            echo "<tr valign='top'><td><b>Prg Name:</b></td><td>" . $this->strPrgname . "</td></tr>";
            echo "<tr valign='top'><td><b>Prg Pfad:</b></td><td>" . $this->strPrgpfad . "</td></tr>";
            echo "<tr valign='top'><td><b>Parameter:</b></td><td>" . $this->strParameter . "</td></tr>";
            echo "<tr valign='top'><td><b>Creator:</b></td><td>" . $this->strCreator . "</td></tr>";
            echo "<tr valign='top'><td><b>Comment:</b></td><td>" . $this->strComment . "</td></tr>";
            echo "<tr valign='top'><td><b>Workpath:</b></td><td>" . $this->strWorkpath . "</td></tr>";
            echo "</td></tr></table>";
        }
    }
?>
