<?php
    /************************************************************************
        Class:          mct_CUser
        Inheritance:    mct_CFileCFG
        Description:    User Object
    ************************************************************************/
    include_once("../inc/mct_general.inc.php");
    include_once("../inc/mct_func.inc.php");
    include_once("../inc/mct_CFileCFG.class.php");
    include_once("../inc/mct_CDebug.class.php");
    include_once("../inc/mct_CDbQuery.class.php");

    class mct_CUser extends mct_CFileCFG
    {
        var $strPassword;   // Defines Password
        var $strIp;         // Defines IP of Host
        var $nRights;       // Defines Height of Right
        var $bTestmode;     // Defines Testmode

        /*-----------------------------------------------------------------------
            CONSTRUCTOR
        -----------------------------------------------------------------------*/
        function mct_CUser($isTestmode = false)
        {
            // Initialize Properties
            $this->mct_init();
            $this->bTestmode = $isTestmode;
            if( ! defined("_TEST_MODE_") && $isTestmode )
                define("_TEST_MODE_",  true);
        }

        /*-----------------------------------------------------------------------
            Method:         Interface Functions
            Description:    get and set Methods for filling the Properties
        -----------------------------------------------------------------------*/
        function mct_getPassword()          { return $this->strPassword; }
        function mct_getIp()                { return $this->strIp;       }
        function mct_getRights()            { return $this->nRights;     }
        function mct_setPassword($strValue, $bMd5 = true)
        {
            if( is_string($strValue) )
            {
                if( $bMd5 ) $this->strPassword = md5($strValue);
                else $this->strPassword = $strValue;
            }
        }
        function mct_setIp($strValue)       { if( is_string($strValue) ) $this->strIp = $strValue;       }
        function mct_setRights($nValue)     { if( is_int($nValue) ) $this->nRights = $nValue;            }

        /*-----------------------------------------------------------------------
            Method:         mct_init
            Description:    Init Properties of Object
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_init()
        {
            parent::mct_init();
            $this->strPassword = "";
            $this->strIp = "";
            $this->nRights = -1;
            $this->bTestmode = false;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_free
            Description:    Free result and clean up
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_free()
        {
            // Free Parent
            parent::mct_free();
            // Set Object to NULL
            $this = null;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_print
            Description:    Print Object
            ---------------------------------------------------------------------
            Parameter:      $bAll            For Parent Object Information
            ---------------------------------------------------------------------
            Return:         -
        -----------------------------------------------------------------------*/
        function mct_print( $bAll = true )
        {
            echo "<hr>";
            echo "<table border='1' cellspacing='0' cellpadding='0'><tr><td>";
            echo "<span style='color:red'><b>CUser Object</b></span>";
            // Check if Print of Parent is desired
            if( $bAll ) parent::mct_print();
            echo "<hr>";
            echo "<b>CUser Object</b><br>";
            echo "<table border='0'>";
            echo "<tr valign='top'><td><b>Password:</b></td><td>*******</td></tr>";
            echo "<tr valign='top'><td><b>Ip:</b></td><td>" . $this->strIp . "</td></tr>";
            echo "<tr valign='top'><td><b>Rights:</b></td><td>" . $this->nRights . "</td></tr>";
            echo "<tr valign='top'><td><b>Testmode:</b></td><td>" . $this->bTestmode . "</td></tr>";
            echo "</table>";
            echo "</td></tr></table>";
        }

        /*-----------------------------------------------------------------------
            Method:         mct_writedb
            Description:    Write or Updates Object to Database
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         Boolean            true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_writedb()
        {
            global $debug;

            $bReturn = false;

            // Create Query-Object
            $objDB = new mct_CDbQuery;

            // Check if Object has an ID
            if( $this->nId == -1 )
            {
                // Get New ID on tconfigfile
                $this->nId = $this->mct_getNewID('tuser');

                // Create INSERT Query
                $objDB->mct_setQuery("INSERT INTO tuser(`ID`, `Name`, `Password`, `Rights`) VALUES("
                    .$this->nId
                    .", '" . $objDB->mct_DBStr($this->strName) . "'"
                    .", '" . $objDB->mct_DBStr($this->strPassword) . "'"
                    .", " . $this->nRights
                    .")");

                // Execute Query
                if( ! $objDB->mct_execute() )
                {
                    // Error happend
                    $objDB->objReturn->mct_print();
                }
                else $bReturn = true;
            }
            // Object has ID, so Update it!
            else
            {
                // Create UPDATE Query
                $objDB->mct_setQuery("UPDATE tuser SET "
                    ."  `Name`='"       . $objDB->mct_DBStr($this->strName) . "'"
                    .", `Password`='"   . $objDB->mct_DBStr($this->strPassword) . "'"
                    .", `Rights`="      . $this->nRights
                    ." WHERE `ID`="      . $this->nId);

                // Execute Query
                if( ! $objDB->mct_execute() )
                {
                    // Error happend
                    $objDB->objReturn->mct_print();
                }
                else $bReturn = true;
            }
            // Free Object
            $objDB->mct_free();
            if( !$bReturn && defined("_DEBUG_MODE_") && isset($debug) ) $debug->mct_add_stack($this, "ERROR", __FILE__, __LINE__);
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_getfromdb
            Description:    Get Object from Database
            ---------------------------------------------------------------------
            Parameter:      $nId            Integer of Record ID
            ---------------------------------------------------------------------
            Return:         Boolean         true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_getfromdb( $nId = -1 )
        {
            global $debug;

            $bReturn = false;
            $objDB = new mct_CDbQuery;

            // Create Query
            $objDB->strQuery = "SELECT * FROM tuser WHERE `ID`=" . $nId;
            // Execute Query
            if( ! $objDB->mct_execute() )
            {
                // Error happpend
                $objDB->objReturn->mct_print();
            }
            elseif( $objDB->mct_getRecordCount() == 0 )
            {
                // Print DB-Object
                //<p> $objDB->mct_print(false);
            }
            else
            {
                // Fill Object with values
                $this->nId = (int)$objDB->objRow->ID;
                $this->strName = $objDB->objRow->Name;
                $this->strPassword = $objDB->objRow->Password;
                $this->strIp = $_SERVER["REMOTE_ADDR"];
                $this->nRights = (int)$objDB->objRow->Rights;
                $bReturn = true;
            }
            $objDB->mct_free();
            if( !$bReturn && defined("_DEBUG_MODE_") && isset($debug) ) $debug->mct_add_stack($this, "ERROR", __FILE__, __LINE__);
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_deletefromdb
            Description:    Delete a Record from a Table
            ---------------------------------------------------------------------
            Return:         Boolean          true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_deletefromdb()
        {
            global $debug;

            $bReturn = false;
            if( $this->nId > -1 )
            {
                $bReturn = parent::mct_deletefromdb($this->nId, "tuser");
            }
            if( !$bReturn && defined("_DEBUG_MODE_") && isset($debug) ) $debug->mct_add_stack($this, "ERROR", __FILE__, __LINE__);
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_getfromdb_byname
            Description:    Writes Userinformation into Object
            ---------------------------------------------------------------------
            Parameter:      $strUserName    Username on DB
            ---------------------------------------------------------------------
            Return:         Boolean         true if Ok, false if faild
        -----------------------------------------------------------------------*/
        function mct_getfromdb_byname( $strUserName = "" )
        {
            global $debug;

            $bReturn = false;

            // Check Parameter
            if( strlen($strUserName) > 0 )
            {
                $objDB = new mct_CDbQuery;

                // Create Query
                $objDB->strQuery = "SELECT * FROM tuser WHERE `Name`='" . $strUserName . "'";
                // Execute Query
                if( ! $objDB->mct_execute() )
                {
                    // Error happend
                    $objDB->objReturn->mct_print();
                }
                elseif( $objDB->mct_getRecordCount() == 0 )
                {
                }
                else
                {
                    // Fill Object with values
                    $this->nId = (int)$objDB->objRow->ID;
                    $this->strName = $objDB->objRow->Name;
                    $this->strPassword = $objDB->objRow->Password;
                    $this->strIp = $_SERVER["REMOTE_ADDR"];
                    $this->nRights = (int)$objDB->objRow->Rights;
                    $bReturn = true;
                }
                $objDB->mct_free();
            }
            if( !$bReturn && defined("_DEBUG_MODE_") && isset($debug) ) $debug->mct_add_stack($this, "ERROR", __FILE__, __LINE__);
            return $bReturn;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_isfilled
            Description:    Checks if User is filled
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         Boolean            true if Filled, else false
        -----------------------------------------------------------------------*/
        function mct_isfilled()
        {
            if( $this->nId != -1 && strlen($this->strName) > 0 && $this->nRights != -1 ) return true;
            else return false;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_isadmin
            Description:    Checks if User is Administrator
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         Boolean            true if Administrator, else false
        -----------------------------------------------------------------------*/
        function mct_isadmin()
        {
            if( $this->nRights > 1 ) return true;
            else return false;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_isdebug
            Description:    Checks if User is Debug-User (+ Administrator)
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         Boolean            true if Debug-User, else false
        -----------------------------------------------------------------------*/
        function mct_isdebug()
        {
            if( $this->nRights > 2 ) return true;
            else return false;
        }

        /*-----------------------------------------------------------------------
            Method:         mct_isTestmode
            Description:    Checks if User logged in with Testmode
            ---------------------------------------------------------------------
            Parameter:      -
            ---------------------------------------------------------------------
            Return:         Boolean            true if Testmode is on, else false
        -----------------------------------------------------------------------*/
        function mct_isTestmode()
        {
            return $this->bTestmode;
        }
    }
?>
