<?php
    /************************************************************************
        Type:           Externe Functions
        Description:    General Function
    ************************************************************************/
    include_once("../inc/mct_general.inc.php");
    include_once("../inc/mct_CReturn.class.php");
    include_once("../inc/mct_CDbQuery.class.php");
    include_once("../inc/mct_CDebug.class.php");

    /*-----------------------------------------------------------------------
        Funktion:       mct_redirect
        Description:    ReDirect to another Address when Header-Information
                        not has been sent yet!
        ---------------------------------------------------------------------
        Parameter:      strSite            String of Site to call
        ---------------------------------------------------------------------
        Return:         -
    -----------------------------------------------------------------------*/
    function mct_redirect( $strSite )
    {
        if ( ! headers_sent())
           if( is_string($strSite) )
              header ("Location:" . $strSite);
         exit;
    }

    /*-----------------------------------------------------------------------
        Funktion:       mct_ConvertPath
        Description:    Convert Path with Slashes
        ---------------------------------------------------------------------
        Parameter:      strValue           String of Path
        ---------------------------------------------------------------------
        Return:         strValue           New converted Path
                        bCheckLast         Check for Last Slash
    -----------------------------------------------------------------------*/
    function mct_ConvertPath($strValue, $bCheckLast = false)
    {
        if( strlen($strValue) > 0 )
        {
            // Convert Backslash to Forwardslash (Syntaxproblems and eliminate DoubleSlashes)
            $strValue = str_replace("\\", "/", $strValue);
            $strValue = str_replace("//", "/", $strValue);

            if( $bCheckLast )
            {
                // Extract Last Character
                $strLast = substr($strValue, strlen($strValue)-1, 1);
                // Check Last Character and Add Slash or Backslash
                if( $strLast != "/" ) $strValue .= "/";
            }
        }
        return $strValue;
    }

    /*-----------------------------------------------------------------------
        Funktion:       mct_ask_extension
        Description:    Check for a loaded extension
        ---------------------------------------------------------------------
        Parameter:      strValue           String of Extension
        ---------------------------------------------------------------------
        Return:         bReturn            true if found, false if not found
    -----------------------------------------------------------------------*/
    function mct_ask_extension( $strValue )
    {
        $bReturn = false;
        $arr = array();
        $arr = get_loaded_extensions();
        $bReturn = in_array($strValue, $arr);
        return $bReturn;
    }


    /*-----------------------------------------------------------------------
        Funktion:       mct_odbc_fetch_object
        Description:    Simulate odbc_fetch_object() when function not in PHP
        ---------------------------------------------------------------------
        Parameter:      res                Ressource-Identifier
        ---------------------------------------------------------------------
        Return:         Object/Boolen      Return Object or false
    -----------------------------------------------------------------------*/
    function mct_odbc_fetch_object($res)
    {
        global $debug;

        if( defined("_DEBUG_MODE_") && isset($debug) && !defined("_MCT_ODBC_FETCH_OBJECT_FUNCTION_") )
        {
            // set define, that the Information only appears one time in the Debugger and not on each call!
            define("_MCT_ODBC_FETCH_OBJECT_FUNCTION_",  true);
            $debug->mct_add_information("Could not find PHP odbc_fetch_object() Function! Use internal mct_odbc_fetch_object()", __FILE__, __LINE__);
        }

        if( ! is_resource($res) )
            return false;
        if( function_exists("odbc_fetch_object") )
            return @odbc_fetch_object($res);

        $rs = array();
        $rs_obj = false;
        if( @odbc_fetch_into($res, $rs) != false )
        {
            foreach( $rs as $key=>$value )
            {
                $fkey = odbc_field_name($res, $key+1);
                $rs_obj->$fkey = trim($value);
            }
        }
        return $rs_obj;
    }

    /*-----------------------------------------------------------------------
        Funktion:       mct_prepare_queryvalue
        Description:    Prepare Query-Value for Valid SQL
        ---------------------------------------------------------------------
        Parameter:      str                String with Query-Value
        ---------------------------------------------------------------------
        Return:         String             Prepared String
    -----------------------------------------------------------------------*/
    function mct_prepare_queryvalue($str)
    {
        return str_replace("'", "''", $str);
    }

    /*-----------------------------------------------------------------------
        Funktion:       mct_write_file
        Description:    writes a string/array to a file
        ---------------------------------------------------------------------
        Parameter:      strFilePath    Path and Filename ("c:\temp\test.txt")
                        varText        String or 1.Dimensional array of text
                        strMode        Mode for opening ('renew' / 'append')
                        bNewLine       New line at the ends
        ---------------------------------------------------------------------
        Return:         Object          Return Object
    -----------------------------------------------------------------------*/
    function mct_write_file( $strFilePath, $varText, $strMode = 'renew', $bNewLine = true )
    {
        global $gCRLF;

        //Define variables
        $nRet = 1;

        //Create Return Object
        $objReturn = new mct_CReturn();

        // check for Save-Mode
        if( defined("_SAVE_MODE_") )
        {
            echo "<p><b>Warning:</b> Action can NOT proceed because SAVE-MODE is ON!</p>";
            $objReturn->mct_setNumber(-1);
            $objReturn->mct_setDescription("<b>Warning:</b> Action can NOT proceed because SAVE-MODE is ON!");
            return $objReturn;
        }

        //Define Mode
        if( $strMode == 'append' ) $mode = 'a';
        else if( $strMode == 'renew' ) $mode = 'w';
        else
        {
            $objReturn->mct_setNumber(-10);
            $objReturn->mct_setDescription("Parameter '" . $strMode . "' failed!");
            return $objReturn;
        }

        //Try to open the file
        if( $h = @fopen($strFilePath, $mode) )
        {
            //Check for array
            if( is_array($varText) )
            {
                //Loop the array
                foreach($varText as $val)
                {
                    //Write value into file
                    if( !$nRet = fputs($h, $val) ) break;
                    //Write LineBreak
                    fputs($h, $gCRLF);
                }
            }
            //Variable is a string
            else
            {
                //Write the string into file
                $nRet = fputs($h, $varText);
            }
            //Check for NewLine and write LineBreak
            if( $nRet && $bNewLine ) $nRet = fputs($h, $gCRLF);

            //Check if fputs failed somewhere
            if( !$nRet )
            {
                $objReturn->mct_setNumber(-1);
                $objReturn->mct_setDescription("File '" . $strFilePath . "' could not be written!");
            }
        }
        //Error on open
        else
        {
            //Check for readable
            if( !is_readable($strFilePath) )
            {
                $objReturn->mct_setNumber(-3);
                $objReturn->mct_setDescription("File '" . $strFilePath . "' is not readable or folder-error!");
            }
            //Check for writeable
            else if( !is_writeable($strFilePath) )
            {
                $objReturn->mct_setNumber(-4);
                $objReturn->mct_setDescription("File '" . $strFilePath . "' is not writeable!");
            }
            //Other Error
            else
            {
                $objReturn->mct_setNumber(-5);
                $objReturn->mct_setDescription("File '" . $strFilePath . "' could not be opend or created!");
            }
        }
        //Close open filehandle
        if( $h ) fclose($h);

        //Check if Object is still empty (-> no error)
        if( ! $objReturn->mct_isfilled() )
        {
            $objReturn->mct_setNumber(1);
            $objReturn->mct_setDescription("File '" . $strFilePath . "' could be written.");
        }

        //Return
        return $objReturn;
    }

    /*-----------------------------------------------------------------------
        Funktion:       mct_read_file
        Description:    reads a file into an array
        ---------------------------------------------------------------------
        Parameter:      strFilePath    Path and Filename ("c:\temp\test.txt")
                        arrText        1.Dimensional array of text
                        nLineBegin     First line to be read (-1 = ignore)
                        nLineEnd       Last line to be read (-1 = ignore)
        ---------------------------------------------------------------------
        Return:          1                succeeded
                        -1                failed - arrText is not an array
                        -2                failed - file not exists
                        -3                failed - file not readable
                        -4                failed - other error
    -----------------------------------------------------------------------*/
    function mct_read_file( $strFilePath, $arrText, $nLineBegin = -1, $nLineEnd = -1 )
    {
        //Define variables
        $nRet = 1;

        //Check for array
        if( !is_array($arrText) )
            return -1;

        //Try to open file
        if( $h = fopen($strFilePath, "r") )
        {
            $i=$cnt=0;

            //Loop file
            while( !feof($h) )
            {
                $cnt++;
                //Get Line from file
                $buffer = fgets($h,1024);
                //Check for limitations
                if( $nLineBegin>=0 && $nLineEnd>=0 )
                {
                    //Check if in range of limitations
                    if( $nLineBegin > $cnt || $nLineEnd < $cnt )
                        continue;
                }
                //Write buffer to array
                $arrText[$i] = $buffer;
                $i++;
            }
        }
        //Error on open
        else
        {
            //Check for existance
            if( !file_exists($strFilePath) )
            {
                echo "Error: File '" . $strFilePath . "' does not exist!";
                $nRet = -2;
            }
            //Check for readable
            else if( !is_readable($strFilePath) )
            {
                echo "Error: File '" . $strFilePath . "' is not readable!";
                $nRet = -3;
            }
            else
            {
                //Other Error
                echo "Error: File '" . $strFilePath . "' could not be opend!";
                $nRet = -4;
            }
        }
        //Close open filehandle
        if( $h ) fclose($h);
        //Return
        return $nRet;
    }

    /*-----------------------------------------------------------------------
        Funktion:       mct_arr2table
        Description:    Generate HTML-Table from Array
        ---------------------------------------------------------------------
        Parameter:      arrTable        2-Dim-Array
        ---------------------------------------------------------------------
        Return:         string          HTML-MCT-Table-String
    -----------------------------------------------------------------------*/
    function mct_arr2table( $arrTable )
    {
        $strHtml = "";
        if( is_array($arrTable) )
        {
            $strHtml = "<table>";
            foreach( $arrTable as $arrTR )
            {
                if( is_array($arrTR) )
                {
                    $strHtml .=  "<tr>";
                    foreach( $arrTR as $strTD )
                    {
                        $strHtml = $strHtml . "<td>" . $strTD . "</td>";
                    }
                    $strHtml .= "</tr>";
                }
            }
            $strHtml .= "</table>";
        }
        return $strHtml;
    }

    /*-----------------------------------------------------------------------
        Funktion:       mct_table2arr
        Description:    Split HTML-Table into Array
        ---------------------------------------------------------------------
        Parameter:      strHtml        HTML-MCT-Table-String
                        strMctTag      Search for Special Tag
        ---------------------------------------------------------------------
        Return:         Array          2-Dim-Array
    -----------------------------------------------------------------------*/
    function mct_table2arr( $strHtml, $strMctTag = "" )
    {
        $arr = array();
        // Search for Spezial Tag
        if( strlen($strMctTag) > 0 ) $strWork = stristr($strHtml, $strMctTag);
        else $strWork = $strHtml;
        $i = 0;
        while( strlen($strWork) > 0 )
        {
            // Get TR-Data
            $nPos = strpos(strtolower($strWork), "<tr>");
            $nPos2 = strpos(strtolower($strWork), "</tr>");
            if( !is_bool($nPos) && !is_bool($nPos2) )
            {
                // Filter Rowstring
                $strRow = substr($strWork, $nPos+4, $nPos2-$nPos-4);
                $ii = 0;
                do
                {
                  // Get TD-Data
                  $nPosRow = strpos(strtolower($strRow), "<td>");
                  $nPosRow2 = strpos(strtolower($strRow), "</td>");
                  if( !is_bool($nPosRow) && !is_bool($nPosRow2) )
                  {
                      // Filter Datastring
                      $strData = substr($strRow, $nPosRow+4, $nPosRow2-$nPosRow-4);

                      // Fill Array-Element
                      if(strlen($strData) > 0) $arr[$i][$ii] = $strData;

                      // Crop Rowstring
                      $strRow = substr($strRow, $nPosRow2+5);
                  } else break;
                  $ii++;
                } while( !is_bool($nPosRow) && !is_bool($nPosRow2) );

                // Crop Workstring
                $strWork = substr($strWork, $nPos2+5);
            } else break;
        $i++;
        }
        return $arr;
    }

    /*-----------------------------------------------------------------------
        Funktion:       mct_ping
        Description:    ping ip and display result
        ---------------------------------------------------------------------
        Parameter:      strIp        Ip to be pinged
        ---------------------------------------------------------------------
        Return:         -
    -----------------------------------------------------------------------*/
    function mct_ping( $strIp )
    {
        echo "<pre>";
        $buffer = system("ping " . $strIp);
        echo $buffer . "</pre>";
    }

    /*-----------------------------------------------------------------------
        Funktion:       mct_write_logfile
        Description:    writes a logfile
        ---------------------------------------------------------------------
        Parameter:      strText        String to be written
                        strLogFile     Logfile
        ---------------------------------------------------------------------
        Return:         -
    -----------------------------------------------------------------------*/
    function mct_write_logfile( $strText, $strLogFile = "logfile.log" )
    {
        $str = date("D d.m.Y H:i:s") . "\t" . $strText;
        $objReturn = mct_write_file( $strLogFile, $str, "append");
        return $objReturn;
    }


    /*-----------------------------------------------------------------------
        Funktion:       mct_write_logfile
        Description:    writes a logfile
        ---------------------------------------------------------------------
        Parameter:      strText        String to be written
                        strLogFile     Logfile
        ---------------------------------------------------------------------
        Return:         -
    -----------------------------------------------------------------------*/
    function mct_write_dblog( $strAction, $strDescription, $nUserId )
    {
        $objDB = new mct_CDbQuery();
        $strDate = date("Y-m-d", time());
        $objDB->mct_setQuery("INSERT INTO tlog(`Date`,`Action`,`Description`,`fkUserID`) VALUES("
            . "  '#" . $strDate . "#'"
            . ", '" . $strAction . "'"
            . ", '" . $strDescription . "'"
            . ",  " . $nUserId
            . ")");
        $objDB->mct_execute();
        $objDB->mct_free();
    }

    /*-----------------------------------------------------------------------
        Funktion:       mct_check_email
        Description:    checks email to be valid
        ---------------------------------------------------------------------
        Parameter:      strEMail    eMail-Address to be checked
        ---------------------------------------------------------------------
        Return:         -
    -----------------------------------------------------------------------*/
    function mct_check_email( $strEMail )
    {
        return( ereg('\@', $strEMail) );
    }

    /*-----------------------------------------------------------------------
        Funktion:       mct_row_count
        Description:    counts all records in a table
        ---------------------------------------------------------------------
        Parameter:      pCon        Pointer to a valid connection
                        strTable    Tablename
        ---------------------------------------------------------------------
        Return:         -
    -----------------------------------------------------------------------*/
    function mct_odbc_row_count( $pCon, $strTable )
    {
        if( strlen($strSelect) ==0 ) return -1;
        $pRes = odbc_exec($pCon, "SELECT count(*) from ". $strTable);
        odbc_fetch_into($pRes, $pArr);
        return $pArr[0];
    }

    /*-----------------------------------------------------------------------
        Funktion:       mct_arr2date
        Description:    Convert DateArray to DateString
        ---------------------------------------------------------------------
        Parameter:      arrDate    1.Dimension DateArray
        ---------------------------------------------------------------------
        Return:         -
    -----------------------------------------------------------------------*/
    function mct_arr2date( $arrDate )
    {
        $tmpDateStamp = mktime(0, 0, 0,  $arrDate["Month"], $arrDate["Day"], $arrDate["Year"]);
        return date("d.m.Y",$tmpDateStamp);
    }

    /*-----------------------------------------------------------------------
        Funktion:       mct_date2arr
        Description:    Convert DateString to DateArray
        ---------------------------------------------------------------------
        Parameter:      $strDate    DateString "22.10.2002"
        ---------------------------------------------------------------------
        Return:          -
    -----------------------------------------------------------------------*/
    function mct_date2arr( $strDate )
    {
        $arrDate["Year"] = substr($strDate, 0 ,4);
        $arrDate["Month"] = substr($strDate, 5 ,2);
        $arrDate["Day"] = substr($strDate, 8 ,2);
        return $arrDate;
    }

    /*-----------------------------------------------------------------------
        Funktion:       mct_date2dbdate
        Description:    Convert DateString to specific DB-DateString
        ---------------------------------------------------------------------
        Parameter:      strDay     String with Day-Number ("28")
                        strMonth   String with Month-Number ("12")
                        strYear    String with Year-Number ("2002")
        ---------------------------------------------------------------------
        Return:            -
    -----------------------------------------------------------------------*/
    function mct_date2dbdate( $strDay, $strMonth, $strYear )
    {
        if( checkdate($strMonth, $strDay, $strYear) ) return "$strDay-$strMonth-$strYear 00:00:00";
        else return false;
    }
?>
